@@ -688,7 +688,7 @@ NV_STATUS NV_API_CALL nv_indicate_not_idle       (nv_state_t *);
 void      NV_API_CALL nv_idle_holdoff            (nv_state_t *);
 
 NvBool    NV_API_CALL nv_dynamic_power_available (nv_state_t *);
-void      NV_API_CALL nv_audio_dynamic_power     (nv_state_t *);
+void      NV_API_CALL nv_audio_dynamic_power     (nv_state_t *, NvBool);
 
 void      NV_API_CALL nv_control_soc_irqs        (nv_state_t *, NvBool bEnable);
 NV_STATUS NV_API_CALL nv_get_current_irq_priv_data(nv_state_t *, NvU32 *);
