@@ -215,9 +215,6 @@ typedef struct UvmGpuChannelInstanceInfo_tag
 
 typedef struct UvmGpuChannelResourceBindParams_tag
 {
-    // In: Ptr to the RM memDesc of the channel resource.
-    NvP64 resourceDescriptor;
-
     // In: RM ID of the channel resource.
     NvU32 resourceId;
 
@@ -407,6 +404,15 @@ typedef struct UvmGpuAllocInfo_tag
     NvHandle hPhysHandle;           // Handle for phys allocation either provided or retrieved
 } UvmGpuAllocInfo;
 
+typedef enum
+{
+    UVM_VIRT_MODE_NONE = 0,             // Baremetal or passthrough virtualization
+    UVM_VIRT_MODE_LEGACY = 1,           // Virtualization without SRIOV support
+    UVM_VIRT_MODE_SRIOV_HEAVY = 2,      // Virtualization with SRIOV Heavy configured
+    UVM_VIRT_MODE_SRIOV_STANDARD = 3,   // Virtualization with SRIOV Standard configured
+    UVM_VIRT_MODE_COUNT = 4,
+} UVM_VIRT_MODE;
+
 // !!! The following enums (with UvmRm prefix) are defined and documented in
 // mm/uvm/interface/uvm_types.h and must be mirrored. Please refer to that file
 // for more details.
@@ -574,6 +580,9 @@ typedef struct UvmGpuInfo_tag
     // Number of subdevices in SLI group.
     NvU32 subdeviceCount;
 
+    // Virtualization mode of this gpu.
+    NvU32 virtMode;         // UVM_VIRT_MODE
+
     // NV_TRUE if this is a simulated/emulated GPU. NV_FALSE, otherwise.
     NvBool isSimulated;
 
