@@ -18,17 +18,6 @@
 
 #define __NVKMS_KAPI_H__
 
-/*
- * On Linux-x86, the kernel's function calling convention may pass
- * parameters in registers.  Force functions called to and from core
- * NVKMS to pass parameters on the stack.
- */
-#if NVCPU_IS_X86
-  #define NVKMS_KAPI_CALL __attribute__((regparm(0)))
-#else
-  #define NVKMS_KAPI_CALL
-#endif
-
 #define NVKMS_KAPI_MAX_HEADS           4
 
 #define NVKMS_KAPI_MAX_CONNECTORS     16
@@ -63,7 +52,7 @@ typedef NvU32 NvKmsKapiDisplay;
  * The callback into NVKMS-KAPI from the channel event proc, may cause
  * deadlock.
  */
-typedef void NVKMS_KAPI_CALL NvKmsChannelEventProc(void *dataPtr, NvU32 dataU32);
+typedef void NvKmsChannelEventProc(void *dataPtr, NvU32 dataU32);
 
 /** @} */
 
@@ -123,6 +112,9 @@ struct NvKmsKapiDeviceResourcesInfo {
 
     struct {
         NvU32 validCursorCompositionModes;
+        NvU32 validOverlayCompositionModes;
+
+        NvU16 validLayerRRTransforms;
 
         NvU32 minWidthInPixels;
         NvU32 maxWidthInPixels;
@@ -162,7 +154,7 @@ struct NvKmsKapiConnectorInfo {
 
     /*
      * List of connectors, not possible to serve together with this connector
-     * becase they are competing for same resources.
+     * because they are competing for same resources.
      */
     NvU32        numIncompatibleConnectors;
     NvKmsKapiConnector incompatibleConnectorHandles[NVKMS_KAPI_MAX_CONNECTORS];
@@ -189,6 +181,7 @@ struct NvKmsKapiStaticDisplayInfo {
 struct NvKmsKapiLayerConfig {
     struct NvKmsKapiSurface *surface;
     struct NvKmsCompositionParams compParams;
+    struct NvKmsRRParams rrParams;
 
     NvU8 minPresentInterval;
     NvBool tearing;
@@ -267,6 +260,17 @@ struct NvKmsKapiEventFlipOccurred {
     NvKmsKapiLayerType layer;
 };
 
+struct NvKmsKapiDpyCRC32 {
+    NvU32 value;
+    NvBool supported;
+};
+
+struct NvKmsKapiCrcs {
+    struct NvKmsKapiDpyCRC32 compositorCrc32;
+    struct NvKmsKapiDpyCRC32 rasterGeneratorCrc32;
+    struct NvKmsKapiDpyCRC32 outputCrc32;
+};
+
 struct NvKmsKapiEvent {
     enum NvKmsEventType type;
 
@@ -369,7 +373,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return  Count of enumerated gpus.
      */
-    NvU32 NVKMS_KAPI_CALL (*enumerateGpus)(nv_gpu_info_t *gpuInfo);
+    NvU32 (*enumerateGpus)(nv_gpu_info_t *gpuInfo);
 
     /*!
      * Allocate an NVK device using which you can query/allocate resources on
@@ -379,7 +383,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return  An valid device handle on success, NULL on failure.
      */
-    struct NvKmsKapiDevice* NVKMS_KAPI_CALL (*allocateDevice)
+    struct NvKmsKapiDevice* (*allocateDevice)
     (
         const struct NvKmsKapiAllocateDeviceParams *params
     );
@@ -390,7 +394,7 @@ struct NvKmsKapiFunctionsTable {
      * \param [in]  device  A device returned by allocateDevice().
      *                      This function is a no-op if device is not valid.
      */
-    void NVKMS_KAPI_CALL (*freeDevice)(struct NvKmsKapiDevice *device);
+    void (*freeDevice)(struct NvKmsKapiDevice *device);
 
     /*!
      * Grab ownership of device, ownership is required to do modeset.
@@ -399,14 +403,14 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*grabOwnership)(struct NvKmsKapiDevice *device);
+    NvBool (*grabOwnership)(struct NvKmsKapiDevice *device);
 
     /*!
      * Release ownership of device.
      *
      * \param [in]  device  A device returned by allocateDevice().
      */
-    void NVKMS_KAPI_CALL (*releaseOwnership)(struct NvKmsKapiDevice *device);
+    void (*releaseOwnership)(struct NvKmsKapiDevice *device);
 
     /*!
      * Registers for notification, via
@@ -424,7 +428,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*declareEventInterest)
+    NvBool (*declareEventInterest)
     (
         const struct NvKmsKapiDevice *device,
         const NvU32 interestMask
@@ -442,7 +446,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getDeviceResourcesInfo)
+    NvBool (*getDeviceResourcesInfo)
     (
         struct NvKmsKapiDevice *device,
         struct NvKmsKapiDeviceResourcesInfo *info
@@ -468,7 +472,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getDisplays)
+    NvBool (*getDisplays)
     (
         struct NvKmsKapiDevice *device,
         NvU32 *numDisplays, NvKmsKapiDisplay *displayHandles
@@ -488,7 +492,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getConnectorInfo)
+    NvBool (*getConnectorInfo)
     (
         struct NvKmsKapiDevice *device,
         NvKmsKapiConnector connector, struct NvKmsKapiConnectorInfo *info
@@ -508,7 +512,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getStaticDisplayInfo)
+    NvBool (*getStaticDisplayInfo)
     (
         struct NvKmsKapiDevice *device,
         NvKmsKapiDisplay display, struct NvKmsKapiStaticDisplayInfo *info
@@ -523,7 +527,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getDynamicDisplayInfo)
+    NvBool (*getDynamicDisplayInfo)
     (
         struct NvKmsKapiDevice *device,
         struct NvKmsKapiDynamicDisplayParams *params
@@ -550,7 +554,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return An valid memory handle on success, NULL on failure.
      */
-    struct NvKmsKapiMemory* NVKMS_KAPI_CALL (*allocateVideoMemory)
+    struct NvKmsKapiMemory* (*allocateVideoMemory)
     (
         struct NvKmsKapiDevice *device,
         enum NvKmsSurfaceMemoryLayout layout,
@@ -578,7 +582,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return An valid memory handle on success, NULL on failure.
      */
-    struct NvKmsKapiMemory* NVKMS_KAPI_CALL (*allocateSystemMemory)
+    struct NvKmsKapiMemory* (*allocateSystemMemory)
     (
         struct NvKmsKapiDevice *device,
         enum NvKmsSurfaceMemoryLayout layout,
@@ -608,7 +612,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return A valid memory handle on success, NULL on failure.
      */
-    struct NvKmsKapiMemory* NVKMS_KAPI_CALL (*importMemory)
+    struct NvKmsKapiMemory* (*importMemory)
     (
         struct NvKmsKapiDevice *device, NvU64 size,
         NvU64 nvKmsParamsUser,
@@ -630,7 +634,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return A valid memory handle on success, NULL on failure.
      */
-    struct NvKmsKapiMemory* NVKMS_KAPI_CALL (*dupMemory)
+    struct NvKmsKapiMemory* (*dupMemory)
     (
         struct NvKmsKapiDevice *device,
         const struct NvKmsKapiDevice *srcDevice,
@@ -659,7 +663,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*exportMemory)
+    NvBool (*exportMemory)
     (
         const struct NvKmsKapiDevice *device,
         const struct NvKmsKapiMemory *memory,
@@ -676,7 +680,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE if memory is in use.
      */
-    void NVKMS_KAPI_CALL (*freeMemory)
+    void (*freeMemory)
     (
         struct NvKmsKapiDevice *device, struct NvKmsKapiMemory *memory
     );
@@ -696,7 +700,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*mapMemory)
+    NvBool (*mapMemory)
     (
         const struct NvKmsKapiDevice *device,
         const struct NvKmsKapiMemory *memory, NvKmsKapiMappingType type,
@@ -715,7 +719,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \param [in]  pLinearAddress   The MMIO address return by mapMemory()
      */
-    void NVKMS_KAPI_CALL (*unmapMemory)
+    void (*unmapMemory)
     (
         const struct NvKmsKapiDevice *device,
         const struct NvKmsKapiMemory *memory, NvKmsKapiMappingType type,
@@ -731,7 +735,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return  An valid surface handle on success.  NULL on failure.
      */
-    struct NvKmsKapiSurface* NVKMS_KAPI_CALL (*createSurface)
+    struct NvKmsKapiSurface* (*createSurface)
     (
         struct NvKmsKapiDevice *device,
         struct NvKmsKapiCreateSurfaceParams *params
@@ -744,7 +748,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \param [in]  surface  A surface created using createSurface()
      */
-    void NVKMS_KAPI_CALL (*destroySurface)
+    void (*destroySurface)
     (
         struct NvKmsKapiDevice *device, struct NvKmsKapiSurface *surface
     );
@@ -771,7 +775,7 @@ struct NvKmsKapiFunctionsTable {
      * \return Value >= 1 if more modes are available, 0 if no more modes are
      *         available, and Value < 0 on failure.
      */
-    int NVKMS_KAPI_CALL (*getDisplayMode)
+    int (*getDisplayMode)
     (
         struct NvKmsKapiDevice *device,
         NvKmsKapiDisplay display, NvU32 modeIndex,
@@ -791,7 +795,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE if mode-timings are valid, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*validateDisplayMode)
+    NvBool (*validateDisplayMode)
     (
         struct NvKmsKapiDevice *device,
         NvKmsKapiDisplay display, const struct NvKmsKapiDisplayMode *mode
@@ -813,7 +817,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*applyModeSetConfig)
+    NvBool (*applyModeSetConfig)
     (
         struct NvKmsKapiDevice *device,
         const struct NvKmsKapiRequestedModeSetConfig *requestedConfig,
@@ -834,7 +838,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getFlipPendingStatus)
+    NvBool (*getFlipPendingStatus)
     (
         const struct NvKmsKapiDevice *device,
         const NvU32 head,
@@ -859,7 +863,7 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return struct NvKmsKapiChannelEvent* on success, NULL on failure.
      */
-    struct NvKmsKapiChannelEvent* NVKMS_KAPI_CALL (*allocateChannelEvent)
+    struct NvKmsKapiChannelEvent* (*allocateChannelEvent)
     (
         struct NvKmsKapiDevice *device,
         NvKmsChannelEventProc *proc,
@@ -876,7 +880,7 @@ struct NvKmsKapiFunctionsTable {
      * \param [in]  cb      struct NvKmsKapiChannelEvent* returned from
      *                      allocateChannelEvent()
      */
-    void NVKMS_KAPI_CALL (*freeChannelEvent)
+    void (*freeChannelEvent)
     (
         struct NvKmsKapiDevice *device,
         struct NvKmsKapiChannelEvent *cb
@@ -895,12 +899,64 @@ struct NvKmsKapiFunctionsTable {
      *
      * \return NV_TRUE on success, NV_FALSE on failure.
      */
-    NvBool NVKMS_KAPI_CALL (*getCRC32)
+    NvBool (*getCRC32)
     (
         struct NvKmsKapiDevice *device,
         NvU32 head,
-        NvU32 *crc32
+        struct NvKmsKapiCrcs *crc32
     );
+
+     /*!
+     * Get the list allocation pages corresponding to the specified memory object.
+     *
+     * \param [in]  device  A device allocated using allocateDevice().
+     *
+     * \param [in]  memory  The memory object for which we need to find the
+     *                      list of allocation pages and number of pages.
+     *
+     * \param [out] pPages  A pointer to the list of NvU64 pointers. Caller
+     *                      should free pPages on success using freeMemoryPages().
+     *
+     * \param [out] pNumPages It gives the total number of NvU64 pointers
+     *                        returned in pPages.
+     *
+     * \return NV_TRUE on success, NV_FALSE on failure.
+     */
+    NvBool (*getMemoryPages)
+    (
+        const struct NvKmsKapiDevice *device,
+        const struct NvKmsKapiMemory *memory,
+        NvU64 **pPages,
+        NvU32 *pNumPages
+    );
+
+    /*!
+     * Free the list of allocation pages returned by getMemoryPages()
+     *
+     * \param [in] pPages  A list of NvU64 pointers allocated by getMemoryPages().
+     *
+     */
+    void (*freeMemoryPages)
+    (
+        NvU64 *pPages
+    );
+
+    /*
+     * Import dma-buf in the memory handle.
+     *
+     * \param [in] device  A device allocated using allocateDevice().
+     *
+     * \param [in] dmaBuf  DMA-BUF pointer.
+     *
+     * \param [in] limit   Size, in bytes, of the dma-buf.
+     *
+     * \return An valid memory handle on success, NULL on failure.
+     */
+    struct NvKmsKapiMemory*
+    (*getSystemMemoryHandleFromDmaBuf)(struct NvKmsKapiDevice *device,
+                                       NvP64 dmaBuf,
+                                       NvU32 limit);
+
 };
 
 /** @} */
@@ -910,7 +966,7 @@ struct NvKmsKapiFunctionsTable {
  * @{
  */
 
-NvBool NVKMS_KAPI_CALL nvKmsKapiGetFunctionsTable
+NvBool nvKmsKapiGetFunctionsTable
 (
     struct NvKmsKapiFunctionsTable *funcsTable
 );
