@@ -259,7 +259,7 @@ extern "C" {
 // Use Coverity Annotation to mark issues as false positives/ignore when using single bit defines.
 #define DRF_ISBIT(bitval,drf)                \
         ( /* coverity[identical_branches] */ \
-          bitval ? drf )
+          (bitval != 0) ? drf )
 #define DEVICE_BASE(d)          (0?d)  // what's up with this name? totally non-parallel to the macros below
 #define DEVICE_EXTENT(d)        (1?d)  // what's up with this name? totally non-parallel to the macros below
 #ifdef NV_MISRA_COMPLIANCE_REQUIRED
@@ -353,8 +353,6 @@ extern "C" {
 #ifdef NV_MISRA_COMPLIANCE_REQUIRED
 #define FLD_SET_DRF(d,r,f,c,v)                  (((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_DEF(d,r,f,c))
 #define FLD_SET_DRF_NUM(d,r,f,n,v)              (((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_NUM(d,r,f,n))
-// FLD_SET_DRF_DEF is deprecated! Use an explicit assignment with FLD_SET_DRF instead.
-#define FLD_SET_DRF_DEF(d,r,f,c,v)              ((v) = ((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_DEF(d,r,f,c))
 #define FLD_IDX_SET_DRF(d,r,f,i,c,v)            (((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f(i))) | DRF_IDX_DEF(d,r,f,i,c))
 #define FLD_IDX_OFFSET_SET_DRF(d,r,f,i,o,c,v)   (((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f(i,o))) | DRF_IDX_OFFSET_DEF(d,r,f,i,o,c))
 #define FLD_IDX_SET_DRF_DEF(d,r,f,i,c,v)        (((NvU32)(v) & ~DRF_SHIFTMASK(NV##d##r##f(i))) | DRF_IDX_DEF(d,r,f,i,c))
@@ -369,8 +367,6 @@ extern "C" {
 #else
 #define FLD_SET_DRF(d,r,f,c,v)                  (((v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_DEF(d,r,f,c))
 #define FLD_SET_DRF_NUM(d,r,f,n,v)              (((v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_NUM(d,r,f,n))
-// FLD_SET_DRF_DEF is deprecated! Use an explicit assignment with FLD_SET_DRF instead.
-#define FLD_SET_DRF_DEF(d,r,f,c,v)              ((v) = ((v) & ~DRF_SHIFTMASK(NV##d##r##f)) | DRF_DEF(d,r,f,c))
 #define FLD_IDX_SET_DRF(d,r,f,i,c,v)            (((v) & ~DRF_SHIFTMASK(NV##d##r##f(i))) | DRF_IDX_DEF(d,r,f,i,c))
 #define FLD_IDX_OFFSET_SET_DRF(d,r,f,i,o,c,v)   (((v) & ~DRF_SHIFTMASK(NV##d##r##f(i,o))) | DRF_IDX_OFFSET_DEF(d,r,f,i,o,c))
 #define FLD_IDX_SET_DRF_DEF(d,r,f,i,c,v)        (((v) & ~DRF_SHIFTMASK(NV##d##r##f(i))) | DRF_IDX_DEF(d,r,f,i,c))
@@ -817,11 +813,19 @@ nvPrevPow2_U32(const NvU32 x )
 //    (Will give unexpected results if 'gran' is not a power of 2.)
 //
 #ifndef NV_ALIGN_DOWN
-#define NV_ALIGN_DOWN(v, gran)      ((v) & ~((gran) - 1))
+//
+// Notably using v - v + gran ensures gran gets promoted to the same type as v if gran has a smaller type.
+// Otherwise, if aligning a NVU64 with NVU32 granularity, the top 4 bytes get zeroed.
+//
+#define NV_ALIGN_DOWN(v, gran)      ((v) & ~((v) - (v) + (gran) - 1))
 #endif
 
 #ifndef NV_ALIGN_UP
-#define NV_ALIGN_UP(v, gran)        (((v) + ((gran) - 1)) & ~((gran)-1))
+//
+// Notably using v - v + gran ensures gran gets promoted to the same type as v if gran has a smaller type.
+// Otherwise, if aligning a NVU64 with NVU32 granularity, the top 4 bytes get zeroed.
+//
+#define NV_ALIGN_UP(v, gran)        (((v) + ((gran) - 1)) & ~((v) - (v) + (gran) - 1))
 #endif
 
 #ifndef NV_ALIGN_DOWN64
