@@ -763,6 +763,11 @@ typedef NvUFXP64                                                   NvUFXP52_12;
 #define NV_TYPES_SFXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)      (NVBIT(32-(x))-1U)
 #define NV_TYPES_SFXP_INTEGER_MAX(x, y)                         (NVBIT((x))-1U)
 #define NV_TYPES_SFXP_INTEGER_MIN(x, y)                      (~(NVBIT((x))-1U))
+#define NV_TYPES_SFXP_S64_SIGN_EXTENSION(x, y)                           63:(x)
+#define NV_TYPES_SFXP_S64_SIGN_EXTENSION_POSITIVE(x, y)      0x0000000000000000
+#define NV_TYPES_SFXP_S64_SIGN_EXTENSION_NEGATIVE(x, y)    (NVBIT64(64-(x))-1U)
+#define NV_TYPES_SFXP_S64_INTEGER_MAX(x, y)                 (NVBIT64((x)-1)-1U)
+#define NV_TYPES_SFXP_S64_INTEGER_MIN(x, y)              (~(NVBIT64((x)-1)-1U))
 
 /*!
  * Conversion macros used for converting between integer and fixed point
@@ -860,6 +865,27 @@ typedef NvUFXP64                                                   NvUFXP52_12;
             1 : 0))
 
 
+//
+// 64-bit Signed FXP:
+// Some compilers do not support left shift negative values
+// so typecast integer to NvU64 instead of NvS64
+//
+#define NV_TYPES_SFXP_X_Y_TO_S64(x, y, fxp)                                   \
+    ((NvS64) ((DRF_VAL64(_TYPES, _FXP, _INTEGER((x), (y)),                      \
+                    ((NvSFXP##x##_##y) (fxp)))) |                             \
+              ((DRF_VAL64(_TYPES, _SFXP, _INTEGER_SIGN((x), (y)), (fxp)) ==     \
+                    NV_TYPES_SFXP_INTEGER_SIGN_NEGATIVE) ?                    \
+                DRF_NUM64(_TYPES, _SFXP, _S64_SIGN_EXTENSION((x), (y)),         \
+                    NV_TYPES_SFXP_S64_SIGN_EXTENSION_NEGATIVE((x), (y))) :    \
+                DRF_NUM64(_TYPES, _SFXP, _S64_SIGN_EXTENSION((x), (y)),         \
+                    NV_TYPES_SFXP_S64_SIGN_EXTENSION_POSITIVE((x), (y))))))
+
+#define NV_TYPES_SFXP_X_Y_TO_S64_ROUNDED(x, y, fxp)                           \
+    (NV_TYPES_SFXP_X_Y_TO_S64(x, y, (fxp)) +                                  \
+        (FLD_TEST_DRF_NUM64(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)),            \
+            NV_TYPES_FXP_FRACTIONAL_MSB_ONE, ((NvSFXP##x##_##y) (fxp))) ?     \
+            1 : 0))
+
 /*!
  * Macros representing the single-precision IEEE 754 floating point format for
  * "binary32", also known as "single" and "float".
