@@ -755,13 +755,18 @@ static struct drm_driver nv_drm_driver = {
 
     .prime_handle_to_fd     = drm_gem_prime_handle_to_fd,
     .prime_fd_to_handle     = drm_gem_prime_fd_to_handle,
-    .gem_prime_export       = drm_gem_prime_export,
     .gem_prime_import       = nv_drm_gem_prime_import,
-    .gem_prime_get_sg_table = nv_drm_gem_prime_get_sg_table,
     .gem_prime_import_sg_table = nv_drm_gem_prime_import_sg_table,
+
+#if defined(NV_DRM_DRIVER_HAS_GEM_PRIME_CALLBACKS)
+    .gem_prime_export       = drm_gem_prime_export,
+    .gem_prime_get_sg_table = nv_drm_gem_prime_get_sg_table,
     .gem_prime_vmap         = nv_drm_gem_prime_vmap,
     .gem_prime_vunmap       = nv_drm_gem_prime_vunmap,
 
+    .gem_vm_ops             = &nv_drm_gem_vma_ops,
+#endif
+
 #if defined(NV_DRM_DRIVER_HAS_GEM_PRIME_RES_OBJ)
     .gem_prime_res_obj      = nv_drm_gem_prime_res_obj,
 #endif
@@ -784,12 +789,11 @@ static struct drm_driver nv_drm_driver = {
     .desc                   = "NVIDIA DRM driver",
     .date                   = "20160202",
 
-#if defined(NV_DRM_DRIVER_HAS_LEGACY_DEV_LIST)
-    .legacy_dev_list        = LIST_HEAD_INIT(nv_drm_driver.legacy_dev_list),
-#else
+#if defined(NV_DRM_DRIVER_HAS_DEVICE_LIST)
     .device_list            = LIST_HEAD_INIT(nv_drm_driver.device_list),
+#elif defined(NV_DRM_DRIVER_HAS_LEGACY_DEV_LIST)
+    .legacy_dev_list        = LIST_HEAD_INIT(nv_drm_driver.legacy_dev_list),
 #endif
-    .gem_vm_ops             = &nv_drm_gem_vma_ops,
 };
 
 
@@ -815,7 +819,7 @@ static void nv_drm_update_drm_driver_features(void)
 
     nv_drm_driver.dumb_create      = nv_drm_dumb_create;
     nv_drm_driver.dumb_map_offset  = nv_drm_dumb_map_offset;
-    nv_drm_driver.dumb_destroy     = drm_gem_dumb_destroy;
+    nv_drm_driver.dumb_destroy     = nv_drm_dumb_destroy;
 #endif /* NV_DRM_ATOMIC_MODESET_AVAILABLE */
 }
 
