@@ -532,4 +532,11 @@ int nv_drm_dumb_map_offset(struct drm_file *file,
     return ret;
 }
 
+int nv_drm_dumb_destroy(struct drm_file *file,
+                        struct drm_device *dev,
+                        uint32_t handle)
+{
+    return drm_gem_handle_delete(file, handle);
+}
+
 #endif
