@@ -94,6 +94,10 @@ int nv_drm_dumb_map_offset(struct drm_file *file,
                            struct drm_device *dev, uint32_t handle,
                            uint64_t *offset);
 
+int nv_drm_dumb_destroy(struct drm_file *file,
+                        struct drm_device *dev,
+                        uint32_t handle);
+
 struct drm_gem_object *nv_drm_gem_nvkms_prime_import(
     struct drm_device *dev,
     struct drm_gem_object *gem);
