@@ -49,6 +49,19 @@
 
 #define NVKMS_LOG_PREFIX "nvidia-modeset: "
 
+/* These parameters are used for fault injection tests.  Normally the defaults
+ * should be used. */
+MODULE_PARM_DESC(fail_malloc, "Fail the Nth call to nvkms_alloc");
+static int fail_malloc_num = -1;
+module_param_named(fail_malloc, fail_malloc_num, int, 0400);
+
+MODULE_PARM_DESC(malloc_verbose, "Report information about malloc calls on module unload");
+static bool malloc_verbose = false;
+module_param_named(malloc_verbose, malloc_verbose, bool, 0400);
+
+static atomic_t nvkms_alloc_called_count;
+
+
 #define NVKMS_SYNCPT_STUBS_NEEDED
 
 /*************************************************************************
@@ -143,6 +156,14 @@
 
 
 
+
+
+
+
+
+
+
+
 
 
 
@@ -154,7 +175,7 @@
 
 #ifdef NVKMS_SYNCPT_STUBS_NEEDED
 /* Unsupported STUB for nvkms_syncpt APIs */
-NvBool NVKMS_API_CALL nvkms_syncpt_op(
+NvBool nvkms_syncpt_op(
     enum NvKmsSyncPtOp op,
     NvKmsSyncPtOpParams *params)
 {
@@ -282,13 +303,22 @@ static inline void nvkms_write_unlock_pm_lock(void)
  * are called while nvkms_lock is held.
  *************************************************************************/
 
-/* Don't use kmalloc for allocations larger than 128k */
-#define KMALLOC_LIMIT (128 * 1024)
+/* Don't use kmalloc for allocations larger than one page */
+#define KMALLOC_LIMIT PAGE_SIZE
 
-void* NVKMS_API_CALL nvkms_alloc(size_t size, NvBool zero)
+void* nvkms_alloc(size_t size, NvBool zero)
 {
     void *p;
 
+    if (malloc_verbose || fail_malloc_num >= 0) {
+        int this_alloc = atomic_inc_return(&nvkms_alloc_called_count) - 1;
+        if (fail_malloc_num >= 0 && fail_malloc_num == this_alloc) {
+            printk(KERN_WARNING NVKMS_LOG_PREFIX "Failing alloc %d\n",
+                   fail_malloc_num);
+            return NULL;
+        }
+    }
+
     if (size <= KMALLOC_LIMIT) {
         p = kmalloc(size, GFP_KERNEL);
     } else {
@@ -302,7 +332,7 @@ void* NVKMS_API_CALL nvkms_alloc(size_t size, NvBool zero)
     return p;
 }
 
-void NVKMS_API_CALL nvkms_free(void *ptr, size_t size)
+void nvkms_free(void *ptr, size_t size)
 {
     if (size <= KMALLOC_LIMIT) {
         kfree(ptr);
@@ -311,42 +341,42 @@ void NVKMS_API_CALL nvkms_free(void *ptr, size_t size)
     }
 }
 
-void* NVKMS_API_CALL nvkms_memset(void *ptr, NvU8 c, size_t size)
+void* nvkms_memset(void *ptr, NvU8 c, size_t size)
 {
     return memset(ptr, c, size);
 }
 
-void* NVKMS_API_CALL nvkms_memcpy(void *dest, const void *src, size_t n)
+void* nvkms_memcpy(void *dest, const void *src, size_t n)
 {
     return memcpy(dest, src, n);
 }
 
-void* NVKMS_API_CALL nvkms_memmove(void *dest, const void *src, size_t n)
+void* nvkms_memmove(void *dest, const void *src, size_t n)
 {
     return memmove(dest, src, n);
 }
 
-int NVKMS_API_CALL nvkms_memcmp(const void *s1, const void *s2, size_t n)
+int nvkms_memcmp(const void *s1, const void *s2, size_t n)
 {
     return memcmp(s1, s2, n);
 }
 
-size_t NVKMS_API_CALL nvkms_strlen(const char *s)
+size_t nvkms_strlen(const char *s)
 {
     return strlen(s);
 }
 
-int NVKMS_API_CALL nvkms_strcmp(const char *s1, const char *s2)
+int nvkms_strcmp(const char *s1, const char *s2)
 {
     return strcmp(s1, s2);
 }
 
-char* NVKMS_API_CALL nvkms_strncpy(char *dest, const char *src, size_t n)
+char* nvkms_strncpy(char *dest, const char *src, size_t n)
 {
     return strncpy(dest, src, n);
 }
 
-void NVKMS_API_CALL nvkms_usleep(NvU64 usec)
+void nvkms_usleep(NvU64 usec)
 {
     if (usec < 1000) {
         /*
@@ -377,7 +407,7 @@ void NVKMS_API_CALL nvkms_usleep(NvU64 usec)
     }
 }
 
-NvU64 NVKMS_API_CALL nvkms_get_usec(void)
+NvU64 nvkms_get_usec(void)
 {
     struct timespec64 ts;
     NvU64 ns;
@@ -388,7 +418,7 @@ NvU64 NVKMS_API_CALL nvkms_get_usec(void)
     return ns / 1000;
 }
 
-int NVKMS_API_CALL nvkms_copyin(void *kptr, NvU64 uaddr, size_t n)
+int nvkms_copyin(void *kptr, NvU64 uaddr, size_t n)
 {
     if (!nvKmsNvU64AddressIsSafe(uaddr)) {
         return -EINVAL;
@@ -401,7 +431,7 @@ int NVKMS_API_CALL nvkms_copyin(void *kptr, NvU64 uaddr, size_t n)
     return 0;
 }
 
-int NVKMS_API_CALL nvkms_copyout(NvU64 uaddr, const void *kptr, size_t n)
+int nvkms_copyout(NvU64 uaddr, const void *kptr, size_t n)
 {
     if (!nvKmsNvU64AddressIsSafe(uaddr)) {
         return -EINVAL;
@@ -414,17 +444,17 @@ int NVKMS_API_CALL nvkms_copyout(NvU64 uaddr, const void *kptr, size_t n)
     return 0;
 }
 
-void NVKMS_API_CALL nvkms_yield(void)
+void nvkms_yield(void)
 {
     schedule();
 }
 
-void NVKMS_API_CALL nvkms_dump_stack(void)
+void nvkms_dump_stack(void)
 {
     dump_stack();
 }
 
-int NVKMS_API_CALL nvkms_snprintf(char *str, size_t size, const char *format, ...)
+int nvkms_snprintf(char *str, size_t size, const char *format, ...)
 {
     int ret;
     va_list ap;
@@ -436,12 +466,12 @@ int NVKMS_API_CALL nvkms_snprintf(char *str, size_t size, const char *format, ..
     return ret;
 }
 
-int NVKMS_API_CALL nvkms_vsnprintf(char *str, size_t size, const char *format, va_list ap)
+int nvkms_vsnprintf(char *str, size_t size, const char *format, va_list ap)
 {
     return vsnprintf(str, size, format, ap);
 }
 
-void NVKMS_API_CALL nvkms_log(const int level, const char *gpuPrefix, const char *msg)
+void nvkms_log(const int level, const char *gpuPrefix, const char *msg)
 {
     const char *levelString;
     const char *levelPrefix;
@@ -466,7 +496,7 @@ void NVKMS_API_CALL nvkms_log(const int level, const char *gpuPrefix, const char
            levelString, NVKMS_LOG_PREFIX, levelPrefix, gpuPrefix, msg);
 }
 
-void NVKMS_API_CALL
+void
 nvkms_event_queue_changed(nvkms_per_open_handle_t *pOpenKernel,
                           NvBool eventsAvailable)
 {
@@ -557,7 +587,7 @@ static void nvkms_free_rm(void)
     __rm_ops.set_callbacks(NULL);
 }
 
-void NVKMS_API_CALL nvkms_call_rm(void *ops)
+void nvkms_call_rm(void *ops)
 {
     nvidia_modeset_stack_ptr stack = NULL;
 
@@ -580,7 +610,7 @@ struct nvkms_ref_ptr {
     void *ptr;
 };
 
-struct nvkms_ref_ptr* NVKMS_API_CALL nvkms_alloc_ref_ptr(void *ptr)
+struct nvkms_ref_ptr* nvkms_alloc_ref_ptr(void *ptr)
 {
     struct nvkms_ref_ptr *ref_ptr = nvkms_alloc(sizeof(*ref_ptr), NV_FALSE);
     if (ref_ptr) {
@@ -591,7 +621,7 @@ struct nvkms_ref_ptr* NVKMS_API_CALL nvkms_alloc_ref_ptr(void *ptr)
     return ref_ptr;
 }
 
-void NVKMS_API_CALL nvkms_free_ref_ptr(struct nvkms_ref_ptr *ref_ptr)
+void nvkms_free_ref_ptr(struct nvkms_ref_ptr *ref_ptr)
 {
     if (ref_ptr) {
         ref_ptr->ptr = NULL;
@@ -600,7 +630,7 @@ void NVKMS_API_CALL nvkms_free_ref_ptr(struct nvkms_ref_ptr *ref_ptr)
     }
 }
 
-void NVKMS_API_CALL nvkms_inc_ref(struct nvkms_ref_ptr *ref_ptr)
+void nvkms_inc_ref(struct nvkms_ref_ptr *ref_ptr)
 {
     nv_kref_get(&ref_ptr->refcnt);
 }
@@ -612,7 +642,7 @@ static void ref_ptr_free(nv_kref_t *ref)
     nvkms_free(ref_ptr, sizeof(*ref_ptr));
 }
 
-void* NVKMS_API_CALL nvkms_dec_ref(struct nvkms_ref_ptr *ref_ptr)
+void* nvkms_dec_ref(struct nvkms_ref_ptr *ref_ptr)
 {
     void *ptr = ref_ptr->ptr;
     nv_kref_put(&ref_ptr->refcnt, ref_ptr_free);
@@ -788,9 +818,9 @@ nvkms_init_timer(struct nvkms_timer_t *timer, nvkms_timer_proc_t *proc,
 }
 
 nvkms_timer_handle_t*
-NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc,
-                                 void *dataPtr, NvU32 dataU32,
-                                 NvU64 usec)
+nvkms_alloc_timer(nvkms_timer_proc_t *proc,
+                  void *dataPtr, NvU32 dataU32,
+                  NvU64 usec)
 {
     // nvkms_alloc_timer cannot be called from an interrupt context.
     struct nvkms_timer_t *timer = nvkms_alloc(sizeof(*timer), NV_FALSE);
@@ -800,7 +830,7 @@ NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc,
     return timer;
 }
 
-NvBool NVKMS_API_CALL
+NvBool
 nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
                                struct nvkms_ref_ptr *ref_ptr,
                                NvU32 dataU32, NvU64 usec)
@@ -818,7 +848,7 @@ nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
     return timer != NULL;
 }
 
-void NVKMS_API_CALL nvkms_free_timer(nvkms_timer_handle_t *handle)
+void nvkms_free_timer(nvkms_timer_handle_t *handle)
 {
     struct nvkms_timer_t *timer = handle;
 
@@ -834,12 +864,12 @@ void NVKMS_API_CALL nvkms_free_timer(nvkms_timer_handle_t *handle)
     timer->cancel = NV_TRUE;
 }
 
-void NVKMS_API_CALL nvkms_get_random(void *ptr, size_t size)
+void nvkms_get_random(void *ptr, size_t size)
 {
     get_random_bytes(ptr, size);
 }
 
-void* NVKMS_API_CALL nvkms_get_per_open_data(int fd)
+void* nvkms_get_per_open_data(int fd)
 {
     struct file *filp = fget(fd);
     struct nvkms_per_open *popen = NULL;
@@ -890,7 +920,7 @@ done:
     return data;
 }
 
-NvBool NVKMS_API_CALL nvkms_fd_is_nvidia_chardev(int fd)
+NvBool nvkms_fd_is_nvidia_chardev(int fd)
 {
     struct file *filp = fget(fd);
     dev_t rdev = 0;
@@ -923,7 +953,7 @@ done:
     return ret;
 }
 
-NvBool NVKMS_API_CALL nvkms_open_gpu(NvU32 gpuId)
+NvBool nvkms_open_gpu(NvU32 gpuId)
 {
     nvidia_modeset_stack_ptr stack = NULL;
     NvBool ret;
@@ -939,7 +969,7 @@ NvBool NVKMS_API_CALL nvkms_open_gpu(NvU32 gpuId)
     return ret;
 }
 
-void NVKMS_API_CALL nvkms_close_gpu(NvU32 gpuId)
+void nvkms_close_gpu(NvU32 gpuId)
 {
     nvidia_modeset_stack_ptr stack = NULL;
 
@@ -952,12 +982,12 @@ void NVKMS_API_CALL nvkms_close_gpu(NvU32 gpuId)
     __rm_ops.free_stack(stack);
 }
 
-NvU32 NVKMS_API_CALL nvkms_enumerate_gpus(nv_gpu_info_t *gpu_info)
+NvU32 nvkms_enumerate_gpus(nv_gpu_info_t *gpu_info)
 {
     return __rm_ops.enumerate_gpus(gpu_info);
 }
 
-NvBool NVKMS_API_CALL nvkms_allow_write_combining(void)
+NvBool nvkms_allow_write_combining(void)
 {
     return __rm_ops.system_info.allow_write_combining;
 }
@@ -1025,7 +1055,7 @@ failed:
     return NULL;
 }
 
-void NVKMS_API_CALL nvkms_close_common(struct nvkms_per_open *popen)
+void nvkms_close_common(struct nvkms_per_open *popen)
 {
     /*
      * Don't use down_interruptible(): we need to free resources
@@ -1063,7 +1093,7 @@ void NVKMS_API_CALL nvkms_close_common(struct nvkms_per_open *popen)
     nvkms_free(popen, sizeof(*popen));
 }
 
-int NVKMS_API_CALL nvkms_ioctl_common
+int nvkms_ioctl_common
 (
     struct nvkms_per_open *popen,
     NvU32 cmd, NvU64 address, const size_t size
@@ -1092,7 +1122,7 @@ int NVKMS_API_CALL nvkms_ioctl_common
  * NVKMS interface for kernel space NVKMS clients like KAPI
  *************************************************************************/
 
-struct nvkms_per_open* NVKMS_API_CALL nvkms_open_from_kapi
+struct nvkms_per_open* nvkms_open_from_kapi
 (
     struct NvKmsKapiDevice *device
 )
@@ -1101,12 +1131,12 @@ struct nvkms_per_open* NVKMS_API_CALL nvkms_open_from_kapi
     return nvkms_open_common(NVKMS_CLIENT_KERNEL_SPACE, device, &status);
 }
 
-void NVKMS_API_CALL nvkms_close_from_kapi(struct nvkms_per_open *popen)
+void nvkms_close_from_kapi(struct nvkms_per_open *popen)
 {
     nvkms_close_common(popen);
 }
 
-NvBool NVKMS_API_CALL nvkms_ioctl_from_kapi
+NvBool nvkms_ioctl_from_kapi
 (
     struct nvkms_per_open *popen,
     NvU32 cmd, void *params_address, const size_t param_size
@@ -1125,7 +1155,7 @@ struct nvkms_sema_t {
     struct semaphore os_sema;
 };
 
-nvkms_sema_handle_t* NVKMS_API_CALL nvkms_sema_alloc(void)
+nvkms_sema_handle_t* nvkms_sema_alloc(void)
 {
     nvkms_sema_handle_t *sema = nvkms_alloc(sizeof(*sema), NV_TRUE);
 
@@ -1136,17 +1166,17 @@ nvkms_sema_handle_t* NVKMS_API_CALL nvkms_sema_alloc(void)
     return sema;
 }
 
-void NVKMS_API_CALL nvkms_sema_free(nvkms_sema_handle_t *sema)
+void nvkms_sema_free(nvkms_sema_handle_t *sema)
 {
     nvkms_free(sema, sizeof(*sema));
 }
 
-void NVKMS_API_CALL nvkms_sema_down(nvkms_sema_handle_t *sema)
+void nvkms_sema_down(nvkms_sema_handle_t *sema)
 {
     down(&sema->os_sema);
 }
 
-void NVKMS_API_CALL nvkms_sema_up(nvkms_sema_handle_t *sema)
+void nvkms_sema_up(nvkms_sema_handle_t *sema)
 {
     up(&sema->os_sema);
 }
@@ -1171,7 +1201,7 @@ void NVKMS_API_CALL nvkms_sema_up(nvkms_sema_handle_t *sema)
 
 struct proc_dir_entry *nvkms_proc_dir;
 
-static void NVKMS_API_CALL nv_procfs_out_string(void *data, const char *str)
+static void nv_procfs_out_string(void *data, const char *str)
 {
     struct seq_file *s = data;
 
@@ -1293,7 +1323,7 @@ static void nvkms_proc_exit(void)
  * NVKMS KAPI functions
  ************************************************************************/
 
-NvBool NVKMS_KAPI_CALL nvKmsKapiGetFunctionsTable
+NvBool nvKmsKapiGetFunctionsTable
 (
     struct NvKmsKapiFunctionsTable *funcsTable
 )
@@ -1447,6 +1477,8 @@ static int __init nvkms_init(void)
 {
     int ret;
 
+    atomic_set(&nvkms_alloc_called_count, 0);
+
     ret = nvkms_alloc_rm();
 
     if (ret != 0) {
@@ -1459,14 +1491,13 @@ static int __init nvkms_init(void)
     ret = nv_kthread_q_init(&nvkms_kthread_q,
                             "nvidia-modeset/kthread_q");
     if (ret != 0) {
-        return ret;
+        goto fail_kthread;
     }
 
     ret = nv_kthread_q_init(&nvkms_deferred_close_kthread_q,
                             "nvidia-modeset/deferred_close_kthread_q");
     if (ret != 0) {
-        nv_kthread_q_stop(&nvkms_kthread_q);
-        return ret;
+        goto fail_deferred_close_kthread;
     }
 
     INIT_LIST_HEAD(&nvkms_timers.list);
@@ -1475,18 +1506,32 @@ static int __init nvkms_init(void)
     ret = nvidia_register_module(&nvidia_modeset_module);
 
     if (ret != 0) {
-        nv_kthread_q_stop(&nvkms_deferred_close_kthread_q);
-        nv_kthread_q_stop(&nvkms_kthread_q);
-        return ret;
+        goto fail_register_module;
     }
 
     down(&nvkms_lock);
-    nvKmsModuleLoad();
+    if (!nvKmsModuleLoad()) {
+        ret = -ENOMEM;
+    }
     up(&nvkms_lock);
+    if (ret != 0) {
+        goto fail_module_load;
+    }
 
     nvkms_proc_init();
 
     return 0;
+
+fail_module_load:
+    nvidia_unregister_module(&nvidia_modeset_module);
+fail_register_module:
+    nv_kthread_q_stop(&nvkms_deferred_close_kthread_q);
+fail_deferred_close_kthread:
+    nv_kthread_q_stop(&nvkms_kthread_q);
+fail_kthread:
+    nvkms_free_rm();
+
+    return ret;
 }
 
 static void __exit nvkms_exit(void)
@@ -1545,6 +1590,11 @@ restart:
 
     nvidia_unregister_module(&nvidia_modeset_module);
     nvkms_free_rm();
+
+    if (malloc_verbose) {
+        printk(KERN_INFO NVKMS_LOG_PREFIX "Total allocations: %d\n",
+               atomic_read(&nvkms_alloc_called_count));
+    }
 }
 
 module_init(nvkms_init);
