@@ -782,6 +782,9 @@ struct uvm_parent_gpu_struct
 
     uvm_gpu_peer_copy_mode_t peer_copy_mode;
 
+    // Virtualization mode of the GPU.
+    UVM_VIRT_MODE virt_mode;
+
     // Whether the GPU can trigger faults on prefetch instructions
     bool prefetch_fault_supported;
 
@@ -804,9 +807,19 @@ struct uvm_parent_gpu_struct
 
     bool has_pulse_based_interrupts;
 
-    // This value is only defined for GPUs that support non-replayable faults
+    // If true, a HW method can be used to clear a faulted channel.
+    // If false, then the GPU supports clearing faulted channels using registers
+    // instead of a HW method.
+    // This value is only defined for GPUs that support non-replayable faults.
     bool has_clear_faulted_channel_method;
 
+    // If true, a SW method can be used to clear a faulted channel.
+    // If false, the HW method or the registers (whichever is available
+    // according to has_clear_faulted_channel_method) needs to be used.
+    //
+    // This value is only defined for GPUs that support non-replayable faults.
+    bool has_clear_faulted_channel_sw_method;
+
     bool sparse_mappings_supported;
 
     // Ampere(GA100) requires map->invalidate->remap->invalidate for page size
@@ -1263,6 +1276,13 @@ static bool uvm_gpu_supports_eviction(uvm_gpu_t *gpu)
     return gpu->parent->replayable_faults_supported;
 }
 
+// Returns true if the virtualization mode is SRIOV-Heavy or SRIOV-Standard.
+static bool uvm_gpu_is_virt_mode_sriov(uvm_gpu_t *gpu)
+{
+    return (gpu->parent->virt_mode == UVM_VIRT_MODE_SRIOV_HEAVY) ||
+           (gpu->parent->virt_mode == UVM_VIRT_MODE_SRIOV_STANDARD);
+}
+
 // Debug print of GPU properties
 void uvm_gpu_print(uvm_gpu_t *gpu);
 
