@@ -201,14 +201,14 @@ static NV_STATUS uvm_isr_top_half(const NvProcessorUuid *gpu_uuid)
     unsigned num_handlers_scheduled = 0;
     NV_STATUS status;
 
-    if (!in_interrupt()) {
-        // Early-out if not in interrupt context. This happens with
-        // CONFIG_DEBUG_SHIRQ enabled where the interrupt handler is called as
-        // part of its removal to make sure it's prepared for being called even
-        // when it's being freed.
+    if (!in_interrupt() && in_atomic()) {
+        // Early-out if we're not in interrupt context, but memory allocations
+        // require GFP_ATOMIC. This happens with CONFIG_DEBUG_SHIRQ enabled,
+        // where the interrupt handler is called as part of its removal to make
+        // sure it's prepared for being called even when it's being freed.
         // This breaks the assumption that the UVM driver is called in atomic
-        // context only in the interrupt context, which
-        // uvm_thread_context_retain() relies on.
+        // context only in the interrupt context, which the thread context
+        // management relies on.
         return NV_OK;
     }
 
@@ -233,13 +233,11 @@ static NV_STATUS uvm_isr_top_half(const NvProcessorUuid *gpu_uuid)
     nv_kref_get(&parent_gpu->gpu_kref);
     uvm_spin_unlock_irqrestore(&g_uvm_global.gpu_table_lock);
 
-    // We don't need an atomic to increment this count since only this top half
-    // writes it, and only one top half can run per GPU at a time.
-    ++parent_gpu->isr.interrupt_count;
-
     // Now that we got a GPU object, lock it so that it can't be removed without us noticing.
     uvm_spin_lock_irqsave(&parent_gpu->isr.interrupts_lock);
 
+    ++parent_gpu->isr.interrupt_count;
+
     if (parent_gpu->isr.is_suspended) {
         status = NV_ERR_NO_INTR_PENDING;
     }
@@ -446,7 +444,6 @@ static uvm_gpu_t *find_first_valid_gpu(uvm_parent_gpu_t *parent_gpu)
     uvm_global_gpu_id_t global_gpu_id = uvm_global_gpu_id_from_gpu_id(parent_gpu->id);
     uvm_gpu_t *gpu;
 
-
     // When SMC is enabled, there's no longer a 1:1 relationship between the
     // parent and the partitions.  But because all relevant interrupt paths
     // are shared, as is the fault reporting logic, it's sufficient here
@@ -471,9 +468,7 @@ static uvm_gpu_t *find_first_valid_gpu(uvm_parent_gpu_t *parent_gpu)
 
         uvm_spin_unlock_irqrestore(&g_uvm_global.gpu_table_lock);
     }
-    else
-
-    {
+    else {
         gpu = uvm_gpu_get(global_gpu_id);
         UVM_ASSERT(gpu != NULL);
     }
