@@ -160,6 +160,7 @@ static uvm_hal_class_ops_t host_table[] =
             .replay_faults = uvm_hal_kepler_replay_faults_unsupported,
             .cancel_faults_targeted = uvm_hal_kepler_cancel_faults_targeted_unsupported,
             .cancel_faults_va = uvm_hal_kepler_cancel_faults_va_unsupported,
+            .clear_faulted_channel_sw_method = uvm_hal_kepler_host_clear_faulted_channel_sw_method_unsupported,
             .clear_faulted_channel_method = uvm_hal_kepler_host_clear_faulted_channel_method_unsupported,
             .clear_faulted_channel_register = uvm_hal_kepler_host_clear_faulted_channel_register_unsupported,
             .access_counter_clear_all = uvm_hal_kepler_access_counter_clear_all_unsupported,
@@ -224,6 +225,7 @@ static uvm_hal_class_ops_t host_table[] =
         .id = AMPERE_CHANNEL_GPFIFO_A,
         .parent_id = TURING_CHANNEL_GPFIFO_A,
         .u.host_ops = {
+            .clear_faulted_channel_sw_method = uvm_hal_ampere_host_clear_faulted_channel_sw_method,
             .clear_faulted_channel_register = uvm_hal_ampere_host_clear_faulted_channel_register,
         }
     },
@@ -545,6 +547,11 @@ NV_STATUS uvm_hal_init_gpu(uvm_parent_gpu_t *parent_gpu)
 void uvm_hal_init_properties(uvm_parent_gpu_t *parent_gpu)
 {
     parent_gpu->arch_hal->init_properties(parent_gpu);
+
+    // Override the HAL when in non-passthrough virtualization
+    // TODO: Bug 200692962: [UVM] Add support for access counters in UVM on SR-IOV configurations
+    if (parent_gpu->virt_mode != UVM_VIRT_MODE_NONE)
+        parent_gpu->access_counters_supported = false;
 }
 
 void uvm_hal_tlb_invalidate_membar(uvm_push_t *push, uvm_membar_t membar)
