@@ -360,6 +360,15 @@ void uvm_hal_kepler_host_clear_faulted_channel_register_unsupported(uvm_user_cha
 void uvm_hal_ampere_host_clear_faulted_channel_register(uvm_user_channel_t *user_channel,
                                                         const uvm_fault_buffer_entry_t *buffer_entry);
 
+typedef void (*uvm_hal_host_clear_faulted_channel_sw_method_t)(uvm_push_t *push,
+                                                               uvm_user_channel_t *user_channel,
+                                                               const uvm_fault_buffer_entry_t *buffer_entry);
+void uvm_hal_kepler_host_clear_faulted_channel_sw_method_unsupported(uvm_push_t *push,
+                                                                     uvm_user_channel_t *user_channel,
+                                                                     const uvm_fault_buffer_entry_t *buffer_entry);
+void uvm_hal_ampere_host_clear_faulted_channel_sw_method(uvm_push_t *push,
+                                                         uvm_user_channel_t *user_channel,
+                                                         const uvm_fault_buffer_entry_t *buffer_entry);
 
 void uvm_hal_print_fault_entry(const uvm_fault_buffer_entry_t *entry);
 void uvm_hal_print_access_counter_buffer_entry(const uvm_access_counter_buffer_entry_t *entry);
@@ -419,6 +428,7 @@ struct uvm_host_hal_struct
     uvm_hal_fault_buffer_replay_t replay_faults;
     uvm_hal_fault_cancel_targeted_t cancel_faults_targeted;
     uvm_hal_fault_cancel_va_t cancel_faults_va;
+    uvm_hal_host_clear_faulted_channel_method_t clear_faulted_channel_sw_method;
     uvm_hal_host_clear_faulted_channel_method_t clear_faulted_channel_method;
     uvm_hal_host_clear_faulted_channel_register_t clear_faulted_channel_register;
     uvm_hal_access_counter_clear_all_t access_counter_clear_all;
