@@ -209,6 +209,13 @@ void uvm_hal_kepler_cancel_faults_va_unsupported(uvm_push_t *push,
     UVM_ASSERT_MSG(false, "host cancel_faults_va called on Kepler GPU\n");
 }
 
+void uvm_hal_kepler_host_clear_faulted_channel_sw_method_unsupported(uvm_push_t *push,
+                                                                     uvm_user_channel_t *user_channel,
+                                                                     const uvm_fault_buffer_entry_t *buffer_entry)
+{
+    UVM_ASSERT_MSG(false, "host clear_faulted_channel_sw_method called on Kepler GPU\n");
+}
+
 void uvm_hal_kepler_host_clear_faulted_channel_method_unsupported(uvm_push_t *push,
                                                                   uvm_user_channel_t *user_channel,
                                                                   const uvm_fault_buffer_entry_t *buffer_entry)
