@@ -307,14 +307,11 @@ static void pde_fill(uvm_page_tree_t *tree,
                      uvm_push_t *push)
 {
     NvU64 pde_data[2], entry_size;
-    NvU32 memsets_per_entry;
     uvm_gpu_address_t pde_entry_addr;
 
     UVM_ASSERT(start_index + pde_count <= uvm_mmu_page_tree_entries(tree, depth, UVM_PAGE_SIZE_AGNOSTIC));
     entry_size = tree->hal->entry_size(depth);
     UVM_ASSERT(sizeof(pde_data) >= entry_size);
-    memsets_per_entry = entry_size / sizeof(pde_data[0]);
-    UVM_ASSERT(memsets_per_entry <= ARRAY_SIZE(pde_data));
 
     tree->hal->make_pde(pde_data, phys_addr, depth);
     pde_entry_addr = uvm_gpu_address_from_phys(directory->addr);
@@ -324,32 +321,42 @@ static void pde_fill(uvm_page_tree_t *tree,
         tree->gpu->parent->ce_hal->memset_8(push, pde_entry_addr, pde_data[0], sizeof(pde_data[0]) * pde_count);
     }
     else {
-        size_t i, j;
+        NvU32 max_inline_entries = UVM_PUSH_INLINE_DATA_MAX_SIZE / sizeof(pde_data);
+        uvm_gpu_address_t inline_data_addr;
+        uvm_push_inline_data_t inline_data;
         NvU32 membar_flag = 0;
+        NvU32 i;
 
         if (uvm_push_get_and_reset_flag(push, UVM_PUSH_FLAG_CE_NEXT_MEMBAR_NONE))
             membar_flag = UVM_PUSH_FLAG_CE_NEXT_MEMBAR_NONE;
         else if (uvm_push_get_and_reset_flag(push, UVM_PUSH_FLAG_CE_NEXT_MEMBAR_GPU))
             membar_flag = UVM_PUSH_FLAG_CE_NEXT_MEMBAR_GPU;
 
-        for (i = 0; i < pde_count; i++) {
-            for (j = 0; j < memsets_per_entry; j++) {
+        for (i = 0; i < pde_count;) {
+            NvU32 j;
+            NvU32 entry_count = min(pde_count - i, max_inline_entries);
 
-                // All but the first memset_8 can be pipelined. We respect the
-                // caller's pipelining settings for the first push.
-                if ((i != 0) || (j != 0))
-                    uvm_push_set_flag(push, UVM_PUSH_FLAG_CE_NEXT_PIPELINED);
+            uvm_push_inline_data_begin(push, &inline_data);
+            for (j = 0; j < entry_count; j++)
+                uvm_push_inline_data_add(&inline_data, pde_data, sizeof(pde_data));
+            inline_data_addr = uvm_push_inline_data_end(&inline_data);
 
-                // No membar is needed until the last copy. Otherwise, use
-                // caller's membar flag.
-                if ((i < (pde_count - 1)) && (j < (memsets_per_entry - 1)))
-                    uvm_push_set_flag(push, UVM_PUSH_FLAG_CE_NEXT_MEMBAR_NONE);
-                else if (membar_flag)
-                    uvm_push_set_flag(push, membar_flag);
+            // All but the first memcopy can be pipelined. We respect the
+            // caller's pipelining settings for the first push.
+            if (i != 0)
+                uvm_push_set_flag(push, UVM_PUSH_FLAG_CE_NEXT_PIPELINED);
 
-                tree->gpu->parent->ce_hal->memset_8(push, pde_entry_addr, pde_data[j], sizeof(pde_data[j]));
-                pde_entry_addr.address += sizeof(pde_data[j]);
-            }
+            // No membar is needed until the last copy. Otherwise, use
+            // caller's membar flag.
+            if (i + entry_count < pde_count)
+                uvm_push_set_flag(push, UVM_PUSH_FLAG_CE_NEXT_MEMBAR_NONE);
+            else if (membar_flag)
+                uvm_push_set_flag(push, membar_flag);
+
+            tree->gpu->parent->ce_hal->memcopy(push, pde_entry_addr, inline_data_addr, entry_count * sizeof(pde_data));
+
+            i += entry_count;
+            pde_entry_addr.address += sizeof(pde_data) * entry_count;
         }
     }
 }
