@@ -156,7 +156,8 @@ static NV_STATUS preferred_location_set(uvm_va_space_t *va_space,
                                         NvU64 base,
                                         NvU64 length,
                                         uvm_processor_id_t preferred_location,
-                                        uvm_va_range_t **first_va_range_to_migrate)
+                                        uvm_va_range_t **first_va_range_to_migrate,
+                                        uvm_tracker_t *out_tracker)
 {
     uvm_va_range_t *va_range, *va_range_last;
     const NvU64 last_address = base + length - 1;
@@ -202,7 +203,7 @@ static NV_STATUS preferred_location_set(uvm_va_space_t *va_space,
                 return NV_ERR_INVALID_DEVICE;
         }
 
-        status = uvm_va_range_set_preferred_location(va_range, preferred_location, mm);
+        status = uvm_va_range_set_preferred_location(va_range, preferred_location, mm, out_tracker);
         if (status != NV_OK)
             return status;
 
@@ -275,7 +276,7 @@ NV_STATUS uvm_api_set_preferred_location(const UVM_SET_PREFERRED_LOCATION_PARAMS
     if (range_is_ats)
         goto done;
 
-    status = preferred_location_set(va_space, mm, start, length, preferred_location_id, &first_va_range_to_migrate);
+    status = preferred_location_set(va_space, mm, start, length, preferred_location_id, &first_va_range_to_migrate, &local_tracker);
     if (status != NV_OK)
         goto done;
 
@@ -316,8 +317,10 @@ done:
 NV_STATUS uvm_api_unset_preferred_location(const UVM_UNSET_PREFERRED_LOCATION_PARAMS *params, struct file *filp)
 {
     NV_STATUS status;
+    NV_STATUS tracker_status;
     uvm_va_space_t *va_space = uvm_va_space_get(filp);
     struct mm_struct *mm = current->mm;
+    uvm_tracker_t local_tracker = UVM_TRACKER_INIT();
 
     UVM_ASSERT(va_space);
 
@@ -327,13 +330,15 @@ NV_STATUS uvm_api_unset_preferred_location(const UVM_UNSET_PREFERRED_LOCATION_PA
     status = uvm_api_range_type_check(va_space, mm, params->requestedBase, params->length);
 
     if (status == NV_OK)
-        status = preferred_location_set(va_space, mm, params->requestedBase, params->length, UVM_ID_INVALID, NULL);
+        status = preferred_location_set(va_space, mm, params->requestedBase, params->length, UVM_ID_INVALID, NULL, &local_tracker);
     else if (status == NV_WARN_NOTHING_TO_DO)
         status = NV_OK;
 
+    tracker_status = uvm_tracker_wait_deinit(&local_tracker);
+
     uvm_va_space_up_write(va_space);
     uvm_up_read_mmap_lock(mm);
-    return status;
+    return status == NV_OK ? tracker_status : status;
 }
 
 static NV_STATUS va_block_set_accessed_by_locked(uvm_va_block_t *va_block,
@@ -410,7 +415,9 @@ static NV_STATUS accessed_by_set(uvm_va_space_t *va_space,
     const NvU64 last_address = base + length - 1;
     bool range_is_sysmem = false;
     accessed_by_split_params_t split_params;
+    uvm_tracker_t local_tracker = UVM_TRACKER_INIT();
     NV_STATUS status;
+    NV_STATUS tracker_status;
 
     UVM_ASSERT(va_space);
 
@@ -465,22 +472,24 @@ static NV_STATUS accessed_by_set(uvm_va_space_t *va_space,
             UVM_ASSERT(uvm_processor_mask_test(&va_range->accessed_by, processor_id) == set_bit);
 
         if (set_bit) {
-            status = uvm_va_range_set_accessed_by(va_range, processor_id, mm);
+            status = uvm_va_range_set_accessed_by(va_range, processor_id, mm, &local_tracker);
             if (status != NV_OK)
                 goto done;
         }
         else {
-            uvm_va_range_unset_accessed_by(va_range, processor_id);
+            uvm_va_range_unset_accessed_by(va_range, processor_id, &local_tracker);
         }
     }
 
     UVM_ASSERT(va_range_last && va_range_last->node.end >= last_address);
 
 done:
+    tracker_status = uvm_tracker_wait_deinit(&local_tracker);
+
     uvm_va_space_up_write(va_space);
     uvm_up_read_mmap_lock(mm);
 
-    return status;
+    return status == NV_OK ? tracker_status : status;
 }
 
 NV_STATUS uvm_api_set_accessed_by(const UVM_SET_ACCESSED_BY_PARAMS *params, struct file *filp)
