@@ -26,7 +26,7 @@
 #ifndef __KERNEL__
 
 #endif
-#include "uvmtypes.h"
+#include "uvm_types.h"
 #include "uvm_ioctl.h"
 #include "nv_uvm_types.h"
 
@@ -42,9 +42,7 @@ typedef struct
 {
     // In params
     NvProcessorUuid gpu_uuid;
-
     NvU32           swizz_id;
-
     // Out params
     NvU64           ref_count NV_ALIGN_BYTES(8);
     NV_STATUS       rmStatus;
@@ -317,19 +315,20 @@ typedef struct
 #define UVM_TEST_TRACKER_SANITY                          UVM_TEST_IOCTL_BASE(12)
 typedef struct
 {
-    NV_STATUS rmStatus; // Out
+    NV_STATUS rmStatus;               // Out
 } UVM_TEST_TRACKER_SANITY_PARAMS;
 
 #define UVM_TEST_PUSH_SANITY                             UVM_TEST_IOCTL_BASE(13)
 typedef struct
 {
-    NV_STATUS rmStatus; // Out
+    NvBool    skipTimestampTest;      // In
+    NV_STATUS rmStatus;               // Out
 } UVM_TEST_PUSH_SANITY_PARAMS;
 
 #define UVM_TEST_CHANNEL_SANITY                          UVM_TEST_IOCTL_BASE(14)
 typedef struct
 {
-    NV_STATUS rmStatus; // Out
+    NV_STATUS rmStatus;               // Out
 } UVM_TEST_CHANNEL_SANITY_PARAMS;
 
 typedef enum
@@ -1182,12 +1181,8 @@ typedef struct
 {
     NvProcessorUuid                 gpu_uuid;                                           // In
     NvHandle                        client;                                             // In
-
     NvHandle                        smc_part_ref;                                       // In
 
-
-
-
     // On kernels with NUMA support, this entry contains the closest CPU NUMA
     // node to this GPU. Otherwise, the value will be -1.
     NvS32                           node_id;                                            // Out
@@ -1210,12 +1205,8 @@ typedef struct
 {
     NvProcessorUuid                 gpu_uuid;                                           // In
     NvHandle                        client;                                             // In
-
     NvHandle                        smc_part_ref;                                       // In
 
-
-
-
     NV_STATUS                       rmStatus;                                           // Out
 } UVM_TEST_NUMA_CHECK_AFFINITY_PARAMS;
 
