@@ -23,7 +23,7 @@
 
 #include "uvm_common.h"
 #include "uvm_linux.h"
-#include "uvmtypes.h"
+#include "uvm_types.h"
 #include "uvm_api.h"
 #include "uvm_va_range.h"
 #include "uvm_va_block.h"
@@ -790,7 +790,7 @@ static void uvm_va_range_disable_peer_managed(uvm_va_range_t *va_range, uvm_gpu_
         // Migration is prevented, but we had to unmap a UVM-Lite GPU. Update
         // the accessed by and UVM-Lite GPUs masks as it cannot be considered a
         // UVM-Lite GPU any more.
-        uvm_va_range_unset_accessed_by(va_range, uvm_lite_gpu_to_unmap->id);
+        uvm_va_range_unset_accessed_by(va_range, uvm_lite_gpu_to_unmap->id, NULL);
     }
 }
 
@@ -833,9 +833,9 @@ static void uvm_va_range_unregister_gpu_managed(uvm_va_range_t *va_range, uvm_gp
     // Note: ignoring the return code of uvm_va_range_set_preferred_location since this
     // will only return on error when setting a preferred location, not on a reset
     if (uvm_id_equal(va_range->preferred_location, gpu->id))
-        (void)uvm_va_range_set_preferred_location(va_range, UVM_ID_INVALID, mm);
+        (void)uvm_va_range_set_preferred_location(va_range, UVM_ID_INVALID, mm, NULL);
 
-    uvm_va_range_unset_accessed_by(va_range, gpu->id);
+    uvm_va_range_unset_accessed_by(va_range, gpu->id, NULL);
 
     // Migrate and free any remaining resident allocations on this GPU
     for_each_va_block_in_va_range(va_range, va_block)
@@ -1191,7 +1191,9 @@ uvm_va_block_t *uvm_va_range_block_next(uvm_va_range_t *va_range, uvm_va_block_t
     return NULL;
 }
 
-static NV_STATUS range_unmap_mask(uvm_va_range_t *va_range, const uvm_processor_mask_t *mask)
+static NV_STATUS range_unmap_mask(uvm_va_range_t *va_range,
+                                  const uvm_processor_mask_t *mask,
+                                  uvm_tracker_t *out_tracker)
 {
     uvm_va_space_t *va_space = va_range->va_space;
     uvm_va_block_context_t *block_context = uvm_va_space_block_context(va_space, NULL);
@@ -1208,6 +1210,9 @@ static NV_STATUS range_unmap_mask(uvm_va_range_t *va_range, const uvm_processor_
 
         uvm_mutex_lock(&block->lock);
         status = uvm_va_block_unmap_mask(block, block_context, mask, region, NULL);
+        if (out_tracker)
+            uvm_tracker_add_tracker_safe(out_tracker, &block->tracker);
+
         uvm_mutex_unlock(&block->lock);
         if (status != NV_OK)
             return status;
@@ -1216,7 +1221,7 @@ static NV_STATUS range_unmap_mask(uvm_va_range_t *va_range, const uvm_processor_
     return NV_OK;
 }
 
-static NV_STATUS range_unmap(uvm_va_range_t *va_range, uvm_processor_id_t processor)
+static NV_STATUS range_unmap(uvm_va_range_t *va_range, uvm_processor_id_t processor, uvm_tracker_t *out_tracker)
 {
     uvm_processor_mask_t mask;
 
@@ -1225,10 +1230,10 @@ static NV_STATUS range_unmap(uvm_va_range_t *va_range, uvm_processor_id_t proces
     uvm_processor_mask_zero(&mask);
     uvm_processor_mask_set(&mask, processor);
 
-    return range_unmap_mask(va_range, &mask);
+    return range_unmap_mask(va_range, &mask, out_tracker);
 }
 
-static NV_STATUS range_map_uvm_lite_gpus(uvm_va_range_t *va_range)
+static NV_STATUS range_map_uvm_lite_gpus(uvm_va_range_t *va_range, uvm_tracker_t *out_tracker)
 {
     NV_STATUS status = NV_OK;
     uvm_va_block_t *va_block;
@@ -1241,7 +1246,8 @@ static NV_STATUS range_map_uvm_lite_gpus(uvm_va_range_t *va_range)
 
     for_each_va_block_in_va_range(va_range, va_block) {
         // UVM-Lite GPUs always map with RWA
-        status = UVM_VA_BLOCK_LOCK_RETRY(va_block, NULL,
+        uvm_mutex_lock(&va_block->lock);
+        status = UVM_VA_BLOCK_RETRY_LOCKED(va_block, NULL,
                 uvm_va_block_map_mask(va_block,
                                       va_block_context,
                                       &va_range->uvm_lite_gpus,
@@ -1249,6 +1255,10 @@ static NV_STATUS range_map_uvm_lite_gpus(uvm_va_range_t *va_range)
                                       NULL,
                                       UVM_PROT_READ_WRITE_ATOMIC,
                                       UvmEventMapRemoteCauseCoherence));
+        if (status == NV_OK && out_tracker)
+            status = uvm_tracker_add_tracker(out_tracker, &va_block->tracker);
+
+        uvm_mutex_unlock(&va_block->lock);
         if (status != NV_OK)
             break;
     }
@@ -1304,7 +1314,8 @@ static void range_update_uvm_lite_gpus_mask(uvm_va_range_t *va_range)
 
 NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range,
                                               uvm_processor_id_t preferred_location,
-                                              struct mm_struct *mm)
+                                              struct mm_struct *mm,
+                                              uvm_tracker_t *out_tracker)
 {
     NV_STATUS status;
     uvm_processor_mask_t all_uvm_lite_gpus;
@@ -1363,7 +1374,7 @@ NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range,
     //  - GPUs that will continue to be UVM-Lite GPUs or are new UVM-Lite GPUs
     //    need to be unmapped so that the new preferred location can be mapped.
     uvm_processor_mask_or(&all_uvm_lite_gpus, &va_range->uvm_lite_gpus, &new_uvm_lite_gpus);
-    status = range_unmap_mask(va_range, &all_uvm_lite_gpus);
+    status = range_unmap_mask(va_range, &all_uvm_lite_gpus, out_tracker);
     if (status != NV_OK)
         return status;
 
@@ -1401,20 +1412,31 @@ NV_STATUS uvm_va_range_set_preferred_location(uvm_va_range_t *va_range,
 
         // Also, mark CPU pages as dirty and remove remote mappings from the new
         // preferred location
-        status = UVM_VA_BLOCK_LOCK_RETRY(va_block,
-                                         NULL,
-                                         uvm_va_block_set_preferred_location_locked(va_block, va_block_context));
+        uvm_mutex_lock(&va_block->lock);
+        status = UVM_VA_BLOCK_RETRY_LOCKED(va_block,
+                                           NULL,
+                                           uvm_va_block_set_preferred_location_locked(va_block, va_block_context));
+
+        if (out_tracker)
+            uvm_tracker_add_tracker_safe(out_tracker, &va_block->tracker);
+
+        uvm_mutex_unlock(&va_block->lock);
+
         if (status != NV_OK)
             return status;
+
     }
 
     // And lastly map all of the current UVM-Lite GPUs to the resident pages on
     // the new preferred location. Anything that's not resident right now will
     // get mapped on the next PreventMigration().
-    return range_map_uvm_lite_gpus(va_range);
+    return range_map_uvm_lite_gpus(va_range, out_tracker);
 }
 
-NV_STATUS uvm_va_range_set_accessed_by(uvm_va_range_t *va_range, uvm_processor_id_t processor_id, struct mm_struct *mm)
+NV_STATUS uvm_va_range_set_accessed_by(uvm_va_range_t *va_range,
+                                       uvm_processor_id_t processor_id,
+                                       struct mm_struct *mm,
+                                       uvm_tracker_t *out_tracker)
 {
     NV_STATUS status;
     uvm_va_block_t *va_block;
@@ -1446,7 +1468,7 @@ NV_STATUS uvm_va_range_set_accessed_by(uvm_va_range_t *va_range, uvm_processor_i
     if (uvm_processor_mask_test(&new_uvm_lite_gpus, processor_id)) {
         // GPUs that become UVM-Lite GPUs need to unmap everything so that they
         // can map the preferred location.
-        status = range_unmap(va_range, processor_id);
+        status = range_unmap(va_range, processor_id, out_tracker);
         if (status != NV_OK)
             return status;
     }
@@ -1464,7 +1486,9 @@ NV_STATUS uvm_va_range_set_accessed_by(uvm_va_range_t *va_range, uvm_processor_i
     return NV_OK;
 }
 
-void uvm_va_range_unset_accessed_by(uvm_va_range_t *va_range, uvm_processor_id_t processor_id)
+void uvm_va_range_unset_accessed_by(uvm_va_range_t *va_range,
+                                    uvm_processor_id_t processor_id,
+                                    uvm_tracker_t *out_tracker)
 {
     uvm_range_group_range_t *rgr = NULL;
 
@@ -1483,7 +1507,7 @@ void uvm_va_range_unset_accessed_by(uvm_va_range_t *va_range, uvm_processor_id_t
     // also stop being a UVM-Lite GPU unless it's also the preferred location.
     if (uvm_processor_mask_test(&va_range->uvm_lite_gpus, processor_id) &&
         !uvm_id_equal(va_range->preferred_location, processor_id)) {
-        range_unmap(va_range, processor_id);
+        range_unmap(va_range, processor_id, out_tracker);
     }
 
     range_update_uvm_lite_gpus_mask(va_range);
