@@ -85,6 +85,10 @@ void uvm_hal_volta_arch_init_properties(uvm_parent_gpu_t *parent_gpu)
 
     parent_gpu->has_pulse_based_interrupts = false;
 
+    // SW method is not currently supported on Volta.
+    // See Bug 3254782: [RM] Support clear_faulted SW method on Volta and Turing
+    parent_gpu->has_clear_faulted_channel_sw_method = false;
+
     parent_gpu->has_clear_faulted_channel_method = true;
 
     parent_gpu->sparse_mappings_supported = true;
