@@ -82,7 +82,7 @@ typedef struct NVSWITCH_CLIENT_EVENT NVSWITCH_CLIENT_EVENT;
  *                                incompatible interface.
  *                                Or, Other NVL_XXX status value.
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_check_api_version
 (
     const char *user_version,
@@ -109,7 +109,7 @@ nvswitch_lib_check_api_version
  * @returns                 NVL_SUCCESS if the action succeeded
  *                          an NVL error code otherwise
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_register_device
 (
     NvU16 pci_domain,
@@ -131,7 +131,7 @@ nvswitch_lib_register_device
  *
  * @returns                 none
  */
-void NVLINK_API_CALL
+void
 nvswitch_lib_unregister_device
 (
     nvswitch_device *device
@@ -148,7 +148,7 @@ nvswitch_lib_unregister_device
  *                          -NVL_BAD_ARGS if bad arguments provided
  *                          -NVL_PCI_ERROR if bar info unable to be retrieved
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_initialize_device
 (
     nvswitch_device *device
@@ -165,7 +165,7 @@ nvswitch_lib_initialize_device
  *                          -NVL_BAD_ARGS if bad arguments provided
  *                          -NVL_PCI_ERROR if bar info unable to be retrieved
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_shutdown_device
 (
     nvswitch_device *device
@@ -186,7 +186,7 @@ nvswitch_lib_shutdown_device
  *                          -NVL_BAD_ARGS if a null arg is provided
  *                          -NVL_ERR_GENERIC otherwise
  */
-NvlStatus NVLINK_API_CALL nvswitch_lib_ctrl
+NvlStatus nvswitch_lib_ctrl
 (
     nvswitch_device *device,
     NvU32 cmd,
@@ -203,7 +203,7 @@ NvlStatus NVLINK_API_CALL nvswitch_lib_ctrl
  * @param[in]  lib_handle   device to query
  * @param[out] pciInfo      return pointer to nvswitch lib copy of device info
  */
-void NVLINK_API_CALL nvswitch_lib_get_device_info
+void nvswitch_lib_get_device_info
 (
     nvswitch_device *lib_handle,
     struct nvlink_pci_info **pciInfo
@@ -223,7 +223,7 @@ void NVLINK_API_CALL nvswitch_lib_get_device_info
  *          -NVL_ERR_NOT_SUPPORTED      device doesn't support this feature
  */
 
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_get_bios_version
 (
     nvswitch_device *device,
@@ -241,7 +241,7 @@ nvswitch_lib_get_bios_version
  *          NV_FALSE                device cannot use PCI pin IRQs
  */
 
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_use_pin_irq
 (
     nvswitch_device *device
@@ -256,7 +256,7 @@ nvswitch_lib_use_pin_irq
  * @return                  NVL_SUCCESS on a successful command
  *                          -NVL_BAD_ARGS if an invalid device is provided
  */
-NvlStatus NVLINK_API_CALL nvswitch_lib_load_platform_info
+NvlStatus nvswitch_lib_load_platform_info
 (
     nvswitch_device *lib_handle
 );
@@ -271,7 +271,7 @@ NvlStatus NVLINK_API_CALL nvswitch_lib_load_platform_info
  * @returns                 NVL_SUCCESS
  *                          -NVL_PCI_ERROR if there was a register access error
  */
-void NVLINK_API_CALL
+void
 nvswitch_lib_enable_interrupts
 (
     nvswitch_device *device
@@ -287,7 +287,7 @@ nvswitch_lib_enable_interrupts
  * @returns                 NVL_SUCCESS
  *                          -NVL_PCI_ERROR if there was a register access error
  */
-void NVLINK_API_CALL
+void
 nvswitch_lib_disable_interrupts
 (
     nvswitch_device *device
@@ -305,7 +305,7 @@ nvswitch_lib_disable_interrupts
  *                          -NVL_PCI_ERROR if there was a register access error
  *                          -NVL_MORE_PROCESSING_REQUIRED no interrupts were found for this device
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_check_interrupts
 (
     nvswitch_device *device
@@ -323,7 +323,7 @@ nvswitch_lib_check_interrupts
  *                          -NVL_PCI_ERROR if there was a register access error
  *                          -NVL_MORE_PROCESSING_REQUIRED no interrupts were found for this device
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_service_interrupts
 (
     nvswitch_device *device
@@ -342,7 +342,7 @@ nvswitch_lib_service_interrupts
  * @returns                 NVL_SUCCESS if there were no errors and interrupts were handled
  *                          -NVL_NOT_FOUND if bad arguments provided
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_get_log_count
 (
     nvswitch_device *device,
@@ -363,7 +363,7 @@ nvswitch_lib_get_log_count
  *
  * @returns nsec interval to wait before the next call.
  */
-NvU64 NVLINK_API_CALL
+NvU64
 nvswitch_lib_deferred_task_dispatcher
 (
     nvswitch_device *device
@@ -379,7 +379,7 @@ nvswitch_lib_deferred_task_dispatcher
  *
  * @returns             returns NvlStatus code, see nvlink_errors.h
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_post_init_device
 (
     nvswitch_device *device
@@ -395,7 +395,7 @@ nvswitch_lib_post_init_device
  *
  * @returns             void
  */
-void NVLINK_API_CALL
+void
 nvswitch_lib_post_init_blacklist_device
 (
     nvswitch_device *device
@@ -412,7 +412,7 @@ nvswitch_lib_post_init_blacklist_device
  *
  * @returns             void
  */
-void NVLINK_API_CALL
+void
 nvswitch_lib_get_uuid
 (
     nvswitch_device *device,
@@ -431,7 +431,7 @@ nvswitch_lib_get_uuid
  * @returns             NVL_SUCCESS if successful
  *                      -NVL_BAD_ARGS if bad arguments provided
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_get_physid
 (
     nvswitch_device *device,
@@ -449,7 +449,7 @@ nvswitch_lib_get_physid
  * @returns                 NVL_SUCCESS if the action succeeded
  *                          -NVL_BAD_ARGS if bad arguments provided
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_read_fabric_state
 (
     nvswitch_device *device,
@@ -467,7 +467,7 @@ nvswitch_lib_read_fabric_state
  *
  * @returns             True if device id is valid
  */
-NvBool NVLINK_API_CALL
+NvBool
 nvswitch_lib_validate_device_id
 (
     NvU32 device_id
@@ -487,7 +487,7 @@ nvswitch_lib_validate_device_id
  *                           -NVL_BAD_ARGS if bad arguments provided
  *                           -NVL_NOT_FOUND if no client event found
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_get_client_event
 (
     nvswitch_device *device,
@@ -509,7 +509,7 @@ nvswitch_lib_get_client_event
  *                       -NVL_BAD_ARGS if bad arguments provided
  *                       -NVL_NO_MEM if allocation fails
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_add_client_event
 (
     nvswitch_device *device,
@@ -528,7 +528,7 @@ nvswitch_lib_add_client_event
  *
  * @returns              NVL_SUCCESS if event removed
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_remove_client_events
 (
     nvswitch_device *device,
@@ -546,7 +546,7 @@ nvswitch_lib_remove_client_events
  * @returns              NVL_SUCCESS if arguments are valid
  *                       -NVL_BAD_ARGS if bad arguments provided
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_lib_notify_client_events
 (
     nvswitch_device *device,
@@ -556,7 +556,7 @@ nvswitch_lib_notify_client_events
 /*
  * Returns count of registered NvSwitch devices.
  */
-NvU32 NVLINK_API_CALL
+NvU32
 nvswitch_os_get_device_count
 (
     void
@@ -566,7 +566,7 @@ nvswitch_os_get_device_count
  * Get current time in nanoseconds
  * The time is since epoch time (midnight UTC of January 1, 1970)
  */
-NvU64 NVLINK_API_CALL
+NvU64
 nvswitch_os_get_platform_time
 (
     void
@@ -582,7 +582,7 @@ nvswitch_os_get_platform_time
 /*
  * printf wrapper
  */
-void NVLINK_API_CALL
+void
 NVSWITCH_PRINT_ATTRIB(2, 3)
 nvswitch_os_print
 (
@@ -594,7 +594,7 @@ nvswitch_os_print
 /*
  * "Registry" interface for dword
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_os_read_registry_dword
 (
     void *os_handle,
@@ -605,7 +605,7 @@ nvswitch_os_read_registry_dword
 /*
  * "Registry" interface for binary data
  */
-NvlStatus NVLINK_API_CALL
+NvlStatus
 nvswitch_os_read_registery_binary
 (
     void *os_handle,
@@ -614,7 +614,7 @@ nvswitch_os_read_registery_binary
     NvU32 length
 );
 
-NvBool NVLINK_API_CALL
+NvBool
 nvswitch_os_is_uuid_in_blacklist
 (
     NvUuid *uuid
@@ -625,7 +625,6 @@ nvswitch_os_is_uuid_in_blacklist
  * Override platform/simulation settings for cases
  */
 void
-NVLINK_API_CALL
 nvswitch_os_override_platform
 (
     void *os_handle,
@@ -636,7 +635,6 @@ nvswitch_os_override_platform
  * Memory management interface
  */
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_alloc_contig_memory
 (
     void *os_handle,
@@ -646,7 +644,6 @@ nvswitch_os_alloc_contig_memory
 );
 
 void
-NVLINK_API_CALL
 nvswitch_os_free_contig_memory
 (
     void *os_handle,
@@ -655,7 +652,6 @@ nvswitch_os_free_contig_memory
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_map_dma_region
 (
     void *os_handle,
@@ -666,7 +662,6 @@ nvswitch_os_map_dma_region
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_unmap_dma_region
 (
     void *os_handle,
@@ -677,7 +672,6 @@ nvswitch_os_unmap_dma_region
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_set_dma_mask
 (
     void *os_handle,
@@ -685,7 +679,6 @@ nvswitch_os_set_dma_mask
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_sync_dma_region_for_cpu
 (
     void *os_handle,
@@ -695,7 +688,6 @@ nvswitch_os_sync_dma_region_for_cpu
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_sync_dma_region_for_device
 (
     void *os_handle,
@@ -705,28 +697,24 @@ nvswitch_os_sync_dma_region_for_device
 );
 
 void *
-NVLINK_API_CALL
 nvswitch_os_malloc
 (
     NvLength size
 );
 
 void
-NVLINK_API_CALL
 nvswitch_os_free
 (
     void *pMem
 );
 
 NvLength
-NVLINK_API_CALL
 nvswitch_os_strlen
 (
     const char *str
 );
 
 char*
-NVLINK_API_CALL
 nvswitch_os_strncpy
 (
     char *pDest,
@@ -735,7 +723,6 @@ nvswitch_os_strncpy
 );
 
 int
-NVLINK_API_CALL
 nvswitch_os_strncmp
 (
     const char *s1,
@@ -744,7 +731,6 @@ nvswitch_os_strncmp
 );
 
 void *
-NVLINK_API_CALL
 nvswitch_os_memset
 (
     void *pDest,
@@ -753,7 +739,6 @@ nvswitch_os_memset
 );
 
 void *
-NVLINK_API_CALL
 nvswitch_os_memcpy
 (
     void *pDest,
@@ -762,7 +747,6 @@ nvswitch_os_memcpy
 );
 
 int
-NVLINK_API_CALL
 nvswitch_os_memcmp
 (
     const void *s1,
@@ -774,14 +758,12 @@ nvswitch_os_memcmp
  * Memory read / write interface
  */
 NvU32
-NVLINK_API_CALL
 nvswitch_os_mem_read32
 (
     const volatile void * pAddress
 );
 
 void
-NVLINK_API_CALL
 nvswitch_os_mem_write32
 (
     volatile void *pAddress,
@@ -789,14 +771,12 @@ nvswitch_os_mem_write32
 );
 
 NvU64
-NVLINK_API_CALL
 nvswitch_os_mem_read64
 (
     const volatile void *pAddress
 );
 
 void
-NVLINK_API_CALL
 nvswitch_os_mem_write64
 (
     volatile void *pAddress,
@@ -807,7 +787,6 @@ nvswitch_os_mem_write64
  * Interface to write formatted output to sized buffer
  */
 int
-NVLINK_API_CALL
 nvswitch_os_snprintf
 (
     char *pString,
@@ -820,7 +799,6 @@ nvswitch_os_snprintf
  * Interface to write formatted output to sized buffer
  */
 int
-NVLINK_API_CALL
 nvswitch_os_vsnprintf
 (
     char *buf,
@@ -833,7 +811,6 @@ nvswitch_os_vsnprintf
  * Debug assert and log interface
  */
 void
-NVLINK_API_CALL
 nvswitch_os_assert_log
 (
     int cond,
@@ -845,14 +822,12 @@ nvswitch_os_assert_log
  * Interface to sleep for specified milliseconds. Yields the CPU to scheduler.
  */
 void
-NVLINK_API_CALL
 nvswitch_os_sleep
 (
     unsigned int ms
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_acquire_fabric_mgmt_cap
 (
     void *osPrivate,
@@ -860,21 +835,18 @@ nvswitch_os_acquire_fabric_mgmt_cap
 );
 
 int
-NVLINK_API_CALL
 nvswitch_os_is_fabric_manager
 (
     void *osPrivate
 );
 
 int
-NVLINK_API_CALL
 nvswitch_os_is_admin
 (
     void
 );
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_get_os_version
 (
     NvU32 *pMajorVer,
@@ -883,7 +855,6 @@ nvswitch_os_get_os_version
 );
 
 void
-NVLINK_API_CALL
 nvswitch_lib_smbpbi_log_sxid
 (
     nvswitch_device *device,
@@ -892,11 +863,46 @@ nvswitch_lib_smbpbi_log_sxid
     ...
 );
 
+/*!
+ * @brief: OS Specific handling to add an event.
+ */
+NvlStatus
+nvswitch_os_add_client_event
+(
+    void            *osHandle,
+    void            *osPrivate,
+    NvU32           eventId
+);
+
+/*!
+ * @brief: OS specific handling to remove all events corresponding to osPrivate.
+ */
+NvlStatus
+nvswitch_os_remove_client_event
+(
+    void            *osHandle,
+    void            *osPrivate
+);
+
+/*!
+ * @brief: OS specific handling to notify an event.
+ */
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_notify_client_event
 (
-    void *osPrivate
+    void *osHandle,
+    void *osPrivate,
+    NvU32 eventId
+);
+
+/*!
+ * @brief: Gets OS specific support for the REGISTER_EVENTS ioctl
+ */
+NvlStatus
+nvswitch_os_get_supported_register_events_params
+(
+    NvBool *bSupportsManyEvents,
+    NvBool *bUserSuppliesOsData
 );
 
 #ifdef __cplusplus
