@@ -1737,7 +1737,6 @@ nvswitch_exit
 // (midnight UTC of January 1, 1970)
 //
 NvU64
-NVLINK_API_CALL
 nvswitch_os_get_platform_time
 (
     void
@@ -1750,7 +1749,6 @@ nvswitch_os_get_platform_time
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_print
 (
     const int  log_level,
@@ -1791,7 +1789,6 @@ nvswitch_os_print
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_override_platform
 (
     void *os_handle,
@@ -1801,7 +1798,6 @@ nvswitch_os_override_platform
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_read_registery_binary
 (
     void *os_handle,
@@ -1814,7 +1810,6 @@ nvswitch_os_read_registery_binary
 }
 
 NvU32
-NVLINK_API_CALL
 nvswitch_os_get_device_count
 (
     void
@@ -1881,7 +1876,6 @@ nvswitch_os_strtouint
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_read_registry_dword
 (
     void *os_handle,
@@ -1972,7 +1966,7 @@ _nvswitch_remove_spaces(const char *in)
  * Compare given string UUID with the NvSwitchBlacklist registry parameter string and
  * return whether the UUID is in the NvSwitch blacklist
  */
-NvBool NVLINK_API_CALL
+NvBool
 nvswitch_os_is_uuid_in_blacklist
 (
     NvUuid *uuid
@@ -2008,7 +2002,6 @@ nvswitch_os_is_uuid_in_blacklist
 
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_alloc_contig_memory
 (
     void *os_handle,
@@ -2038,7 +2031,6 @@ nvswitch_os_alloc_contig_memory
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_free_contig_memory
 (
     void *os_handle,
@@ -2064,7 +2056,6 @@ _nvswitch_to_pci_dma_direction
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_map_dma_region
 (
     void *os_handle,
@@ -2094,7 +2085,6 @@ nvswitch_os_map_dma_region
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_unmap_dma_region
 (
     void *os_handle,
@@ -2118,7 +2108,6 @@ nvswitch_os_unmap_dma_region
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_set_dma_mask
 (
     void *os_handle,
@@ -2137,7 +2126,6 @@ nvswitch_os_set_dma_mask
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_sync_dma_region_for_cpu
 (
     void *os_handle,
@@ -2160,7 +2148,6 @@ nvswitch_os_sync_dma_region_for_cpu
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_sync_dma_region_for_device
 (
     void *os_handle,
@@ -2183,27 +2170,56 @@ nvswitch_os_sync_dma_region_for_device
 }
 
 void *
-NVLINK_API_CALL
 nvswitch_os_malloc
 (
     NvLength size
 )
 {
-   return kmalloc(size, GFP_KERNEL);
+    void *ptr = NULL;
+
+    if (!NV_MAY_SLEEP())
+    {
+        if (size <= NVSWITCH_KMALLOC_LIMIT)
+        {
+            ptr = kmalloc(size, NV_GFP_ATOMIC);
+        }
+    }
+    else
+    {
+        if (size <= NVSWITCH_KMALLOC_LIMIT)
+        {
+            ptr = kmalloc(size, NV_GFP_NO_OOM);
+        }
+
+        if (ptr == NULL)
+        {
+            ptr = vmalloc(size);
+        }
+    }
+
+    return ptr;
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_free
 (
     void *ptr
 )
 {
-    return kfree(ptr);
+    if (!ptr)
+        return;
+
+    if (is_vmalloc_addr(ptr))
+    {
+        vfree(ptr);
+    }
+    else
+    {
+        kfree(ptr);
+    }
 }
 
 NvLength
-NVLINK_API_CALL
 nvswitch_os_strlen
 (
     const char *str
@@ -2213,7 +2229,6 @@ nvswitch_os_strlen
 }
 
 char*
-NVLINK_API_CALL
 nvswitch_os_strncpy
 (
     char *dest,
@@ -2225,7 +2240,6 @@ nvswitch_os_strncpy
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_strncmp
 (
     const char *s1,
@@ -2237,7 +2251,6 @@ nvswitch_os_strncmp
 }
 
 void *
-NVLINK_API_CALL
 nvswitch_os_memset
 (
     void *dest,
@@ -2249,7 +2262,6 @@ nvswitch_os_memset
 }
 
 void *
-NVLINK_API_CALL
 nvswitch_os_memcpy
 (
     void *dest,
@@ -2261,7 +2273,6 @@ nvswitch_os_memcpy
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_memcmp
 (
     const void *s1,
@@ -2273,7 +2284,6 @@ nvswitch_os_memcmp
 }
 
 NvU32
-NVLINK_API_CALL
 nvswitch_os_mem_read32
 (
     const volatile void * address
@@ -2283,7 +2293,6 @@ nvswitch_os_mem_read32
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_mem_write32
 (
     volatile void *address,
@@ -2294,7 +2303,6 @@ nvswitch_os_mem_write32
 }
 
 NvU64
-NVLINK_API_CALL
 nvswitch_os_mem_read64
 (
     const volatile void * address
@@ -2304,7 +2312,6 @@ nvswitch_os_mem_read64
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_mem_write64
 (
     volatile void *address,
@@ -2315,7 +2322,6 @@ nvswitch_os_mem_write64
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_snprintf
 (
     char *dest,
@@ -2335,7 +2341,6 @@ nvswitch_os_snprintf
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_vsnprintf
 (
     char *buf,
@@ -2348,7 +2353,6 @@ nvswitch_os_vsnprintf
 }
 
 void
-NVLINK_API_CALL
 nvswitch_os_assert_log
 (
     int cond,
@@ -2377,7 +2381,6 @@ nvswitch_os_assert_log
  * Sleep for specified milliseconds. Yields the CPU to scheduler.
  */
 void
-NVLINK_API_CALL
 nvswitch_os_sleep
 (
     unsigned int ms
@@ -2399,7 +2402,6 @@ nvswitch_os_sleep
 }
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_acquire_fabric_mgmt_cap
 (
     void *osPrivate,
@@ -2426,7 +2428,6 @@ nvswitch_os_acquire_fabric_mgmt_cap
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_is_fabric_manager
 (
     void *osPrivate
@@ -2445,7 +2446,6 @@ nvswitch_os_is_fabric_manager
 }
 
 int
-NVLINK_API_CALL
 nvswitch_os_is_admin
 (
     void
@@ -2459,7 +2459,6 @@ nvswitch_os_is_admin
 #define NV_KERNEL_SUBVERSION ((LINUX_VERSION_CODE)       & 0x0ff)
 
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_get_os_version
 (
     NvU32 *pMajorVer,
@@ -2477,11 +2476,42 @@ nvswitch_os_get_os_version
     return NVL_SUCCESS;
 }
 
+/*!
+ * @brief: OS specific handling to add an event.
+ */
+NvlStatus
+nvswitch_os_add_client_event
+(
+    void            *osHandle,
+    void            *osPrivate,
+    NvU32           eventId
+)
+{
+    return NVL_SUCCESS;
+}
+
+/*!
+ * @brief: OS specific handling to remove all events corresponding to osPrivate.
+ */
+NvlStatus
+nvswitch_os_remove_client_event
+(
+    void            *osHandle,
+    void            *osPrivate
+)
+{
+    return NVL_SUCCESS;
+}
+
+/*!
+ * @brief: OS specific handling to notify an event.
+ */
 NvlStatus
-NVLINK_API_CALL
 nvswitch_os_notify_client_event
 (
-    void *osPrivate
+    void *osHandle,
+    void *osPrivate,
+    NvU32 eventId
 )
 {
     nvswitch_file_private_t *private_data = (nvswitch_file_private_t *)osPrivate;
@@ -2494,5 +2524,20 @@ nvswitch_os_notify_client_event
     private_data->file_event.event_pending = NV_TRUE;
     wake_up_interruptible(&private_data->file_event.wait_q_event);
 
-    return NV_OK;
+    return NVL_SUCCESS;
+}
+
+/*!
+ * @brief: Gets OS specific support for the REGISTER_EVENTS ioctl
+ */
+NvlStatus
+nvswitch_os_get_supported_register_events_params
+(
+    NvBool *many_events,
+    NvBool *os_descriptor
+)
+{
+    *many_events   = NV_FALSE;
+    *os_descriptor = NV_FALSE;
+    return NVL_SUCCESS;
 }
