@@ -971,6 +971,20 @@ void NV_API_CALL nv_dma_enable_nvlink
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -987,22 +1001,34 @@ void NV_API_CALL nv_dma_enable_nvlink
 
 
 #if IMPORT_STUBS_NEEDED == 1
+NV_STATUS NV_API_CALL nv_dma_import_dma_buf
+(
+    nv_dma_device_t *dma_dev,
+    struct dma_buf *dma_buf,
+    NvU32 *size,
+    void **user_pages,
+    nv_dma_buf_t **import_priv
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 NV_STATUS NV_API_CALL nv_dma_import_from_fd
 (
     nv_dma_device_t *dma_dev,
     NvS32 fd,
     NvU32 *size,
     void **user_pages,
-    void **import_priv
+    nv_dma_buf_t **import_priv
 )
 {
     return NV_ERR_NOT_SUPPORTED;
 }
 
-void NV_API_CALL nv_dma_release_from_fd
+void NV_API_CALL nv_dma_release_dma_buf
 (
     void *user_pages,
-    void *import_priv
+    nv_dma_buf_t *import_priv
 )
 {
 }
