@@ -315,6 +315,8 @@ static NV_STATUS nv_alloc_coherent_pages(
                                   NV_MEMORY_UNCACHED);
     }
 
+    at->is_coherent = NV_TRUE;
+
     return NV_OK;
 }
 
@@ -370,6 +372,15 @@ NV_STATUS nv_alloc_contig_pages(
     }
     if (virt_addr == 0)
     {
+        if (os_is_vgx_hyper())
+        {
+            nv_printf(NV_DBG_MEMINFO,
+                "NVRM: VM: %s: failed to allocate memory, trying coherent memory \n", __FUNCTION__);
+
+            status = nv_alloc_coherent_pages(nv, at);
+            return status;
+        }
+
         nv_printf(NV_DBG_MEMINFO,
             "NVRM: VM: %s: failed to allocate memory\n", __FUNCTION__);
         return NV_ERR_NO_MEMORY;
@@ -407,6 +418,8 @@ NV_STATUS nv_alloc_contig_pages(
                                   NV_MEMORY_UNCACHED);
     }
 
+    at->is_coherent = NV_FALSE;
+
     return NV_OK;
 
 failed:
@@ -432,7 +445,7 @@ void nv_free_contig_pages(
     nv_printf(NV_DBG_MEMINFO,
             "NVRM: VM: %s: %u pages\n", __FUNCTION__, at->num_pages);
 
-    if (os_is_xen_dom0())
+    if (at->is_coherent == NV_TRUE)
         return nv_free_coherent_pages(at);
 
     if (at->cache_type != NV_MEMORY_CACHED)
