@@ -901,14 +901,14 @@ void NV_API_CALL os_unmap_kernel_space(
 }
 
 // flush the cpu's cache, uni-processor version
-NV_STATUS NV_API_CALL os_flush_cpu_cache()
+NV_STATUS NV_API_CALL os_flush_cpu_cache(void)
 {
     CACHE_FLUSH();
     return NV_OK;
 }
 
 // flush the cache of all cpus
-NV_STATUS NV_API_CALL os_flush_cpu_cache_all()
+NV_STATUS NV_API_CALL os_flush_cpu_cache_all(void)
 {
 #if defined(NVCPU_FAMILY_ARM)
     CACHE_FLUSH_ALL();
@@ -921,12 +921,7 @@ NV_STATUS NV_API_CALL os_flush_cpu_cache_all()
     return NV_ERR_NOT_SUPPORTED;
 }
 
-// Flush and/or invalidate a range of memory
-// start, end are the virtual addresses
-// physStart, physEnd are the corresponding physical addresses
-// Start addresses are inclusive, end addresses exclusive
-NV_STATUS NV_API_CALL os_flush_user_cache(NvU64 start, NvU64 end,
-                                          NvU64 physStart, NvU64 physEnd)
+NV_STATUS NV_API_CALL os_flush_user_cache(void)
 {
 #if defined(NVCPU_FAMILY_ARM)
     if (!NV_MAY_SLEEP())
@@ -941,13 +936,6 @@ NV_STATUS NV_API_CALL os_flush_user_cache(NvU64 start, NvU64 end,
     // safe.
     //
     CACHE_FLUSH_ALL();
-#else
-    // Flush L1 cache
-    __cpuc_flush_dcache_area((void *)(NvU32)start, (NvU32)(end-start));
-#if defined(OUTER_FLUSH_RANGE)
-    // Now flush L2 cache.
-    OUTER_FLUSH_RANGE((NvU32)physStart, (NvU32)physEnd);
-#endif
 #endif
 
     return NV_OK;
@@ -956,7 +944,7 @@ NV_STATUS NV_API_CALL os_flush_user_cache(NvU64 start, NvU64 end,
 #endif
 }
 
-void NV_API_CALL os_flush_cpu_write_combine_buffer()
+void NV_API_CALL os_flush_cpu_write_combine_buffer(void)
 {
     WRITE_COMBINE_FLUSH();
 }
